@@ -1,86 +1,83 @@
 import sys
-import unittest
 
-from PyQt5 import QtGui, QtWidgets
-from PyQt5.QtGui import *
-from PyQt5.QtTest import QTest
-from PyQt5 import QtCore
-from unittest.mock import MagicMock
+import pytest
 
-# set up import paths
-import path_prepare
+from PySide6 import QtGui, QtWidgets
+from PySide6.QtGui import *
+from PySide6.QtTest import QTest
+from PySide6 import QtCore
 
 # Local
 from sas.qtgui.MainWindow.MainWindow import MainSasViewWindow
 from sas.qtgui.MainWindow.MainWindow import SplashScreen
 from sas.qtgui.Perspectives.Fitting import FittingPerspective
+from sas.qtgui.Utilities.HidableDialog import HidableDialog, ShowAgainResult
 
-if not QtWidgets.QApplication.instance():
-    app = QtWidgets.QApplication(sys.argv)
-
-class MainWindowTest(unittest.TestCase):
+from sas.system import config
+class MainWindowTest:
     """Test the Main Window GUI"""
-    def setUp(self):
-        """Create the GUI"""
+
+    def __init__(self):
+        config.override_with_defaults() # Disable saving of test file
+        config.LAST_WHATS_NEW_HIDDEN_VERSION = "999.999.999" # Give a very large version number
+
+    @pytest.fixture(autouse=True)
+    def widget(self, qapp):
+        '''Create/Destroy the GUI'''
         screen_resolution = QtCore.QRect(0, 0, 640, 480)
-        self.widget = MainSasViewWindow(screen_resolution, None)
+        w = MainSasViewWindow(screen_resolution, None)
 
-    def tearDown(self):
-        """Destroy the GUI"""
-        self.widget = None
+        yield w
 
-    def testDefaults(self):
+    def testDefaults(self, widget):
         """Test the GUI in its default state"""
-        self.assertIsInstance(self.widget, QtWidgets.QMainWindow)
-        self.assertIsInstance(self.widget.centralWidget(), QtWidgets.QMdiArea)
-        self.assertTrue(self.widget.workspace.horizontalScrollBarPolicy() ==
-                        QtCore.Qt.ScrollBarAsNeeded)
-        self.assertTrue(self.widget.workspace.verticalScrollBarPolicy() ==
-                        QtCore.Qt.ScrollBarAsNeeded)
+        assert isinstance(widget, QtWidgets.QMainWindow)
+        assert isinstance(widget.centralWidget(), QtWidgets.QMdiArea)
+        assert widget.workspace.horizontalScrollBarPolicy() == \
+                        QtCore.Qt.ScrollBarAsNeeded
+        assert widget.workspace.verticalScrollBarPolicy() == \
+                        QtCore.Qt.ScrollBarAsNeeded
 
-    def testSplashScreen(self):
+    def testSplashScreen(self, qapp):
         """ Test the splash screen """
         splash = SplashScreen()
-        self.assertIsInstance(splash, QtWidgets.QSplashScreen)
+        assert isinstance(splash, QtWidgets.QSplashScreen)
 
-    def testWidgets(self):
+    def testWidgets(self, qapp):
         """ Test enablement/disablement of widgets """
         # Open the main window
         screen_resolution = QtCore.QRect(0, 0, 640, 480)
         tmp_main = MainSasViewWindow(screen_resolution, None)
         tmp_main.showMaximized()
         # See that only one subwindow is up
-        self.assertEqual(len(tmp_main.workspace.subWindowList()), 3)
+        assert len(tmp_main.workspace.subWindowList()) == 3
         # and that the subwindow is the fitting perspective
-        self.assertIsInstance(tmp_main.workspace.subWindowList()[0].widget(),
-                              FittingPerspective.FittingWindow)
+        assert isinstance(tmp_main.workspace.subWindowList()[0].widget(), FittingPerspective.FittingWindow)
         # Show the message widget
         tmp_main.guiManager.showWelcomeMessage()
         # Assure it is visible and a part of the MdiArea
-        self.assertEqual(len(tmp_main.workspace.subWindowList()), 3)
+        assert len(tmp_main.workspace.subWindowList()) == 3
 
-        tmp_main.close()
-
-    def testPerspectiveChanges(self):
+    @pytest.mark.xfail(reason="2022-09 already broken - input file issue")
+    def testPerspectiveChanges(self, widget):
         """
         Test all information is retained on perspective change
         """
         def check_after_load(name):
-            self.assertEqual(name, gui.perspective().name)
-            self.assertEqual(1, len(gui.perspective().currentTabDataId()))
-            self.assertTrue(
-                (gui.perspective().currentTabDataId()[0]) in dataIDList)
+            assert name == gui.perspective().name
+            assert 1 == len(gui.perspective().currentTabDataId())
+            assert (gui.perspective().currentTabDataId()[0]) in dataIDList
 
         # Base definitions
         FIT = 'Fitting'
         PR = 'Inversion'
-        gui = self.widget.guiManager
+        gui = widget.guiManager
         filesWidget = gui.filesWidget
         currentPers = filesWidget.cbFitting
         sendDataButton = filesWidget.cmdSendTo
         # Verify defaults
-        self.assertTrue(hasattr(gui, 'loadedPerspectives'))
-        self.assertEqual(4, len(gui.loadedPerspectives))
+        assert hasattr(gui, 'loadedPerspectives')
+        assert 4 == len(gui.loadedPerspectives)
         # Load data
         file = ["cyl_400_20.txt"]
         filesWidget.readData(file)
@@ -101,13 +98,14 @@ class MainWindowTest(unittest.TestCase):
         currentPers.setCurrentIndex(currentPers.findText(PR))
         check_after_load(PR)
 
-    def testExit(self):
+    def testExit(self, qapp, mocker):
         """
         Test that the custom exit method is called on shutdown
         """
         # Must mask sys.exit, otherwise the whole testing process stops.
-        sys.exit = MagicMock()
-        QtWidgets.QMessageBox.question = MagicMock(return_value=QtWidgets.QMessageBox.Yes)
+        mocker.patch.object(sys, 'exit')
+        # mocker.patch.object(QtWidgets.QMessageBox, 'question', return_value=QtWidgets.QMessageBox.Yes)
+        mocker.patch.object(HidableDialog, 'exec', return_value=1)
 
         # Open, then close the main window
         screen_resolution = QtCore.QRect(0, 0, 640, 480)
@@ -115,8 +113,4 @@ class MainWindowTest(unittest.TestCase):
         tmp_main.close()
 
         # See that the MessageBox method got called
-        self.assertTrue(QtWidgets.QMessageBox.question.called)
-
-
-if __name__ == "__main__":
-    unittest.main()
+        assert HidableDialog.exec.called_once()
