@@ -1,16 +1,16 @@
-from distutils.command.config import config
-
 import numpy
 import copy
 
-from PyQt5 import QtCore
-from PyQt5 import QtGui
-from PyQt5 import QtWidgets
+from typing import Optional
+
+from PySide6 import QtCore
+from PySide6 import QtGui
+from PySide6 import QtWidgets
 
 from bumps import options
-from bumps import fitters
 
-import sas.qtgui.Utilities.LocalConfig as LocalConfig
+from sas.system.config import config
+
 import sas.qtgui.Utilities.ObjectLibrary as ObjectLibrary
 import sas.qtgui.Utilities.GuiUtils as GuiUtils
 from sas.qtgui.Perspectives.Fitting.Constraint import Constraint
@@ -19,19 +19,28 @@ from sas.qtgui.Perspectives.Fitting.FittingWidget import FittingWidget
 from sas.qtgui.Perspectives.Fitting.ConstraintWidget import ConstraintWidget
 from sas.qtgui.Perspectives.Fitting.FittingOptions import FittingOptions
 from sas.qtgui.Perspectives.Fitting.GPUOptions import GPUOptions
+from sas.qtgui.Perspectives.perspective import Perspective
 
-class FittingWindow(QtWidgets.QTabWidget):
+from sas.qtgui.Utilities.Reports.reportdata import ReportData
+
+class FittingWindow(QtWidgets.QTabWidget, Perspective):
     """
     """
-    tabsModifiedSignal = QtCore.pyqtSignal()
-    fittingStartedSignal = QtCore.pyqtSignal(list)
-    fittingStoppedSignal = QtCore.pyqtSignal(list)
+    tabsModifiedSignal = QtCore.Signal()
+    fittingStartedSignal = QtCore.Signal(list)
+    fittingStoppedSignal = QtCore.Signal(list)
+
+    name = "Fitting"
+    ext = "fitv"
+
+    @property
+    def title(self):
+        """ Window title"""
+        return "Fitting Perspective"
 
-    name = "Fitting" # For displaying in the combo box in DataExplorer
-    ext = "fitv"  # Extension used for saving analyses
     def __init__(self, parent=None, data=None):
 
-        super(FittingWindow, self).__init__()
+        super().__init__()
 
         self.parent = parent
         self._data = data
@@ -42,9 +51,6 @@ class FittingWindow(QtWidgets.QTabWidget):
         # Max index for adding new, non-clashing tab names
         self.maxIndex = 1
 
-        # The default optimizer
-        self.optimizer = 'Levenberg-Marquardt'
-
         # Dataset index -> Fitting tab mapping
         self.dataToFitTab = {}
 
@@ -65,25 +71,20 @@ class FittingWindow(QtWidgets.QTabWidget):
         self.fittingStartedSignal.connect(self.onFittingStarted)
         self.fittingStoppedSignal.connect(self.onFittingStopped)
 
-        self.communicate.copyFitParamsSignal.connect(self.onParamCopy)
-        self.communicate.pasteFitParamsSignal.connect(self.onParamPaste)
-        self.communicate.copyExcelFitParamsSignal.connect(self.onExcelCopy)
-        self.communicate.copyLatexFitParamsSignal.connect(self.onLatexCopy)
-        self.communicate.SaveFitParamsSignal.connect(self.onParamSave)
-
         # Perspective window not allowed to close by default
         self._allow_close = False
 
         # Fit options - uniform for all tabs
         self.fit_options = options.FIT_CONFIG
-        self.fit_options_widget = FittingOptions(self, config=self.fit_options)
-        self.fit_options.selected_id = fitters.MPFit.id
+        self.fit_options_widget = FittingOptions(config=self.fit_options)
+        self.fit_options.selected_id = config.config.FITTING_DEFAULT_OPTIMIZER
+        self.optimizer = self.fit_options.selected_name
 
         # Listen to GUI Manager signal updating fit options
         self.fit_options_widget.fit_option_changed.connect(self.onFittingOptionsChange)
 
         # GPU Options
-        self.gpu_options_widget = GPUOptions(self)
+        self.gpu_options_widget = GPUOptions()
 
         self.updateWindowTitle()
 
@@ -94,6 +95,7 @@ class FittingWindow(QtWidgets.QTabWidget):
         self.plusButton.setToolTip("Add a new Fit Page")
         self.plusButton.clicked.connect(lambda: self.addFit(None))
 
+
     def updateWindowTitle(self):
         """
         Update the window title with the current optimizer name
@@ -110,17 +112,25 @@ class FittingWindow(QtWidgets.QTabWidget):
 
         self._allow_close = value
 
-    def onParamCopy(self):
-        self.currentTab.onCopyToClipboard("")
+    def clipboard_copy(self):
+        if self.currentFittingWidget is not None:
+            self.currentFittingWidget.clipboard_copy()
 
-    def onParamPaste(self):
-        self.currentTab.onParameterPaste()
+    def clipboard_paste(self):
+        if self.currentFittingWidget is not None:
+            self.currentFittingWidget.clipboard_paste()
 
-    def onExcelCopy(self):
-        self.currentTab.onCopyToClipboard("Excel")
+    def excel_clipboard_copy(self):
+        if self.currentFittingWidget is not None:
+            self.currentFittingWidget.clipboard_copy_excel()
 
-    def onLatexCopy(self):
-        self.currentTab.onCopyToClipboard("Latex")
+    def latex_clipboard_copy(self):
+        if self.currentFittingWidget is not None:
+            self.currentFittingWidget.clipboard_copy_latex()
+
+    def save_parameters(self):
+        if self.currentFittingWidget is not None:
+            self.currentFittingWidget.save_parameters()
 
     def serializeAll(self):
         return self.serializeAllFitpage()
@@ -169,6 +179,10 @@ class FittingWindow(QtWidgets.QTabWidget):
                 state[i] = {'fit_params': [line_dict]}
         return state
 
+    @property
+    def preferences(self):
+        return [self.fit_options_widget, self.gpu_options_widget]
+
     def currentTabDataId(self):
         """
         Returns the data ID of the current tab
@@ -206,12 +220,11 @@ class FittingWindow(QtWidgets.QTabWidget):
                     constraint.param = constraint_param[1]
                     constraint.value_ex = constraint_param[2]
                     constraint.validate = constraint_param[3]
+                    model_key = tab.getModelKey(constraint)
                     tab.addConstraintToRow(constraint=constraint,
                                            row=tab.getRowFromName(
-                                               constraint_param[1]))
-
-    def onParamSave(self):
-        self.currentTab.onCopyToClipboard("Save")
+                                               constraint_param[1]),
+                                           model_key=model_key)
 
     def closeEvent(self, event):
         """
@@ -498,12 +511,20 @@ class FittingWindow(QtWidgets.QTabWidget):
         return state
 
     @property
-    def currentTab(self):
+    def currentTab(self): # TODO: More pythonic name
         """
         Returns the tab widget currently shown
         """
         return self.currentWidget()
 
+    @property
+    def currentFittingWidget(self) -> Optional[FittingWidget]:
+        current_tab = self.currentTab
+        if isinstance(current_tab, FittingWidget):
+            return current_tab
+        else:
+            return None
+
     def getFitTabs(self):
         """
         Returns the list of fitting tabs
@@ -519,9 +540,9 @@ class FittingWindow(QtWidgets.QTabWidget):
         constraints = []
         for tab in self.getFitTabs():
             tab_name = tab.modelName()
-            tab_constraints = tab.getConstraintsForModel()
-            constraints.extend((tab_name + "." + par, expr)
-                               for par, expr in tab_constraints)
+            tab_constraints = tab.getConstraintsForAllModels()
+            constraints.extend((tab_name + "." + par, expr) for par, expr in tab_constraints)
+
         return constraints
 
     def getSymbolDictForConstraints(self):
@@ -555,3 +576,32 @@ class FittingWindow(QtWidgets.QTabWidget):
             if tab.modelName() == name:
                 return tab
         return None
+
+    @property
+    def supports_reports(self) -> bool:
+        return True
+
+    def getReport(self) -> Optional[ReportData]:
+        """ Get the report from the current tab"""
+        fitting_widget = self.currentFittingWidget
+        return None if fitting_widget is None else fitting_widget.getReport()
+
+    @property
+    def supports_fitting_menu(self) -> bool:
+        return True
+
+    @property
+    def supports_copy(self) -> bool:
+        return True
+
+    @property
+    def supports_copy_excel(self) -> bool:
+        return True
+
+    @property
+    def supports_copy_latex(self) -> bool:
+        return True
+
+    @property
+    def supports_paste(self) -> bool:
+        return True
\ No newline at end of file
