@@ -1,12 +1,11 @@
 import copy
 
-from PyQt5 import QtCore
-from PyQt5 import QtGui
+from PySide6 import QtCore
+from PySide6 import QtGui
 
 import numpy
 
-from sas.qtgui.Plotting.PlotterData import Data1D
-from sas.qtgui.Plotting.PlotterData import Data2D
+from sas.qtgui.Plotting.PlotterData import Data1D, DataRole, Data2D
 
 from sas.qtgui.Perspectives.Fitting.AssociatedComboBox import AssociatedComboBox
 
@@ -187,8 +186,8 @@ def addSimpleParametersToModel(parameters, is2D, parameters_original=None, model
     Actually appends to model, if model and view params are not None.
     Always returns list of lists of QStandardItems.
 
-    parameters_original: list of parameters before any tagging on their IDs, e.g. for product model (so that those are
-    the display names; see below)
+    parameters_original: list of parameters before any tagging on their IDs,
+    e.g. for product model (so that those are the display names; see below)
     """
     if is2D:
         params = [p for p in parameters.kernel_parameters if p.type != 'magnetic']
@@ -196,8 +195,9 @@ def addSimpleParametersToModel(parameters, is2D, parameters_original=None, model
         params = parameters.iq_parameters
 
     if parameters_original:
-        # 'parameters_original' contains the parameters as they are to be DISPLAYED, while 'parameters'
-        # contains the parameters as they were renamed; this is for handling name collisions in product model.
+        # 'parameters_original' contains the parameters as they are to be DISPLAYED,
+        # while 'parameters' contains the parameters as they were renamed;
+        # this is for handling name collisions in product model.
         # The 'real name' of the parameter will be stored in the item's user data.
         if is2D:
             params_orig = [p for p in parameters_original.kernel_parameters if p.type != 'magnetic']
@@ -435,7 +435,8 @@ def calculateChi2(reference_data, current_data, weight):
 
         if index is None:
             index = numpy.ones(len(current_data.y), dtype=bool)
-        if current_data.dy is None or current_data.dy == []:
+        # if current_data.dy is None or not len(current_data.dy):
+        if current_data.dy is None or current_data.dy.size == 0:
             dy = numpy.ones(len(current_data.y))
         else:
             dy = weight
@@ -493,7 +494,7 @@ def residualsData1D(reference_data, current_data, weights):
     weight = None
 
     # 1d theory from model_thread is only in the range of index
-    if current_data.dy is None or current_data.dy == []:
+    if current_data.dy is None or not len(current_data.dy):
         dy = numpy.ones(len(current_data.y))
     else:
         #dy = weight if weight is not None else numpy.ones(len(current_data.y))
@@ -549,7 +550,7 @@ def residualsData1D(reference_data, current_data, weights):
     residuals.ytransform = 'y'
     if reference_data.isSesans:
         residuals.xtransform = 'x'
-        residuals.xaxis('\\rm{z} ', 'A')
+        residuals.xaxis('\\delta ', 'A')
     # For latter scale changes
     else:
         residuals.xaxis('\\rm{Q} ', 'A^{-1}')
@@ -643,13 +644,14 @@ def plotPolydispersities(model):
         data1d.symbol = 'Line'
         data1d.name = "{} polydispersity".format(name)
         data1d.id = data1d.name # placeholder, has to be completed later
-        data1d.plot_role = Data1D.ROLE_RESIDUAL
+        data1d.plot_role = DataRole.ROLE_POLYDISPERSITY
         plots.append(data1d)
     return plots
 
 def binary_encode(i, digits):
     return [i >> d & 1 for d in range(digits)]
 
+
 def getWeight(data, is2d, flag=None):
     """
     Received flag and compute error on data.
@@ -677,8 +679,95 @@ def getWeight(data, is2d, flag=None):
         weight = numpy.sqrt(numpy.abs(data))
     elif flag == 3:
         weight = numpy.abs(data)
+
     return weight
 
+
+def getRelativeError(data, is2d, flag=None):
+    """
+    Return dy/y.
+    """
+    weight = None
+    if data is None:
+        return []
+    if is2d:
+        if not hasattr(data, 'err_data'):
+            return numpy.ones_like(data.y)
+        dy_data = data.err_data
+        data = data.data
+    else:
+        if not hasattr(data, 'dy'):
+            return numpy.ones_like(data.y)
+        dy_data = data.dy
+        data = data.y
+
+    if flag == 0:
+        weight = numpy.ones_like(data)
+    elif flag == 1:
+        weight = dy_data / data
+    elif flag == 2:
+        weight = 1.0 / numpy.sqrt(numpy.abs(data))
+    elif flag == 3:
+        weight = 1.0 / numpy.abs(data)
+
+    return weight
+
+def calcWeightIncrease(weights, ratios, flag=False):
+    """ Calculate the weights to be passed to bumps in order to ensure
+        that each data set contributes to the total residual with a
+        relative weight roughly proportional to the ratios defined by
+        the user when the "Modify weighting" option is employed.
+
+        The influence of each data set in the global fit is approximately
+        proportional to the number of points and to (1/sigma^2), or
+        probably better to (1/relative_error^2) = (intensity/sigma)^2.
+
+        Therefore in order to try to give equal weights to each data set
+        in the global fitting, we can compute the total relative weight
+        of each data set as the sum (y_i/dy_i**2) over all the points in
+        the data set and then renormalize them using:
+
+        user_weight[dataset] * sqrt(min(relative_weights) /  relative_weights[dataset])
+
+        If all user weights are one (the default), this will decrease the weight
+        of the data sets initially contributing more to the global fit, while
+        keeping the weight of the initially smaller contributor equal to one.
+
+        These weights are stored for each data set (FitPage) in a dictionary that
+        will be then used by bumps to modify the weights of each set.
+
+        Warning: As bumps uses the data set weights to multiply the residuals
+        calculated as (y-f(x))/sigma, it would probably make sense to include
+        the value of user_weight[dataset] in the square root, but as in any
+        case this is just a qualitative way of increasing/decreasing the weight
+        of some datasets and there is not a real mathematical justification
+        behind, this provides a more intuitive behaviour for the user, who will
+        see that the final weights of the data sets vary proportionally to changes
+        in the input user weights.
+
+    :param weights: Dictionary of data for the statistical weight, typical the y axis error
+    :type weights: dict of numpy.ndarray
+    :param ratios: Desired relative statistical weight ratio between the different datasets.
+    :type ratios: dict
+    :param flag: Boolean indicating if the weight of the datasets should be modified or not,
+                 which depends on the "Modify weighting" box in the Simultaneous Fit tab
+                 being checked or not
+    :type flag: bool
+    :return: Weight multiplier for each dataset
+    :rtype: dict
+    """
+
+    # If "Modify weighting" option not checked
+    if not flag:
+        return {k: 1.0 for k in weights}
+
+    # Calc statistical weight for each dataset and maximum
+    stat_weights = {k: numpy.sum(v**-2) for k, v in weights.items()}
+    min_weight = min(stat_weights.values())
+    weight_increase = {k: float(ratios[k]) * numpy.sqrt(min_weight / v) for k, v in stat_weights.items()}
+
+    return weight_increase
+
 def updateKernelWithResults(kernel, results):
     """
     Takes model kernel and applies results dict to its parameters,
@@ -693,7 +782,6 @@ def updateKernelWithResults(kernel, results):
 
     return local_kernel
 
-
 def getStandardParam(model=None):
     """
     Returns a list with standard parameters for the current model
@@ -769,31 +857,21 @@ def getOrientationParam(kernel_module=None):
 
     return param
 
-def formatParameters(parameters, Check=True):
+def formatParameters(parameters: list, entry_sep=',', line_sep=':'):
     """
     Prepare the parameter string in the standard SasView layout
     """
-    assert parameters is not None
-    assert isinstance(parameters, list)
-    output_string = "sasview_parameter_values:"
+
+    parameter_strings = ["sasview_parameter_values"]
     for parameter in parameters:
-        # recast tuples into strings
-        parameter = [str(p) for p in parameter]
-        output_string += ",".join([p for p in parameter if p is not None])
-        output_string += ":"
+        parameter_strings.append(entry_sep.join([str(component) for component in parameter]))
 
-    if Check == False:
-        new_string = output_string.replace(':', '\n')
-        return new_string
-    else:
-        return output_string
+    return line_sep.join(parameter_strings)
 
-def formatParametersExcel(parameters):
+def formatParametersExcel(parameters: list):
     """
     Prepare the parameter string in the Excel format (tab delimited)
     """
-    assert parameters is not None
-    assert isinstance(parameters, list)
     crlf = chr(13) + chr(10)
     tab = chr(9)
 
@@ -804,29 +882,32 @@ def formatParametersExcel(parameters):
     check = ""
     for parameter in parameters:
         names += parameter[0]+tab
-        # Add the error column if fitted
-        if parameter[1] == "True" and parameter[3] is not None:
-            names += parameter[0]+"_err"+tab
+        if len(parameter) > 3:
+            # Add the error column if fitted
+            if parameter[1] == "True" and parameter[3] is not None:
+                names += parameter[0]+"_err"+tab
 
-        values += parameter[2]+tab
-        check += parameter[1]+tab
-        if parameter[1] == "True" and parameter[3] is not None:
-            values += parameter[3]+tab
-        # add .npts and .nsigmas when necessary
-        if parameter[0][-6:] == ".width":
-            names += parameter[0].replace('.width', '.nsigmas') + tab
-            names += parameter[0].replace('.width', '.npts') + tab
-            values += parameter[5] + tab + parameter[4] + tab
+            values += parameter[2]+tab
+            check += str(parameter[1])+tab
+            if parameter[1] == "True" and parameter[3] is not None:
+                values += parameter[3]+tab
+            # add .npts and .nsigmas when necessary
+            if parameter[0][-6:] == ".width":
+                names += parameter[0].replace('.width', '.nsigmas') + tab
+                names += parameter[0].replace('.width', '.npts') + tab
+                values += parameter[5] + tab + parameter[4] + tab
+        else:
+            # Empty statement for debugging purposes
+            pass
 
     output_string = names + crlf + values + crlf + check
     return output_string
 
-def formatParametersLatex(parameters):
+def formatParametersLatex(parameters: list):
     """
     Prepare the parameter string in latex
     """
-    assert parameters is not None
-    assert isinstance(parameters, list)
+
     output_string = r'\begin{table}'
     output_string += r'\begin{tabular}[h]'
 
@@ -836,46 +917,43 @@ def formatParametersLatex(parameters):
     output_string += r'}\hline'
     output_string += crlf
 
+    names = ""
+    values = ""
+
     for index, parameter in enumerate(parameters):
         name = parameter[0] # Parameter name
-        output_string += name.replace('_', r'\_')  # Escape underscores
-        # Add the error column if fitted
-        if parameter[1] == "True" and parameter[3] is not None:
-            output_string += ' & '
-            output_string += parameter[0]+r'\_err'
-
-        if index < len(parameters) - 1:
-            output_string += ' & '
-
-        # add .npts and .nsigmas when necessary
-        if parameter[0][-6:] == ".width":
-            output_string += parameter[0].replace('.width', '.nsigmas') + ' & '
-            output_string += parameter[0].replace('.width', '.npts')
+        names += name.replace('_', r'\_')  # Escape underscores
+        if len(parameter) > 3:
+            values += f" {parameter[2]}"
+            # Add the error column if fitted
+            if parameter[1] == "True" and parameter[3] is not None:
+                names += f" & {parameter[0]} " + r'\_err'
+                values += f' & {parameter[3]}'
 
             if index < len(parameters) - 1:
-                output_string += ' & '
+                names += ' & '
+                values += ' & '
 
+            # add .npts and .nsigmas when necessary
+            if parameter[0][-6:] == ".width":
+                names += parameter[0].replace('.width', '.nsigmas') + ' & '
+                names += parameter[0].replace('.width', '.npts')
+                values += parameter[5] + ' & '
+                values += parameter[4]
+
+                if index < len(parameters) - 1:
+                    names += ' & '
+                    values += ' & '
+        elif len(parameter) > 2:
+            values += f' & {parameter[2]} &'
+        else:
+            values += f' & {parameter[1]} &'
+
+    output_string += names
     output_string += r'\\ \hline'
     output_string += crlf
 
-    # Construct row of values and errors
-    for index, parameter in enumerate(parameters):
-        output_string += parameter[2]
-        if parameter[1] == "True" and parameter[3] is not None:
-            output_string += ' & '
-            output_string += parameter[3]
-
-        if index < len(parameters) - 1:
-            output_string += ' & '
-
-        # add .npts and .nsigmas when necessary
-        if parameter[0][-6:] == ".width":
-            output_string += parameter[5] + ' & '
-            output_string += parameter[4]
-
-            if index < len(parameters) - 1:
-                output_string += ' & '
-
+    output_string += values
     output_string += r'\\ \hline'
     output_string += crlf
     output_string += r'\end{tabular}'
@@ -887,9 +965,15 @@ def isParamPolydisperse(param_name, kernel_params, is2D=False):
     """
     Simple lookup for polydispersity for the given param name
     """
+    # First, check if this is a polydisperse parameter directly
+    if '.width' in param_name:
+        return True
+
     parameters = kernel_params.form_volume_parameters
     if is2D:
         parameters += kernel_params.orientation_parameters
+
+    # Next, check if the parameter is included in para.polydisperse
     has_poly = False
     for param in parameters:
         if param.name==param_name and param.polydisperse:
