@@ -3,18 +3,19 @@ import logging
 import copy
 import numpy as np
 
-from PyQt5 import QtCore
-from PyQt5 import QtGui, QtWidgets
+from PySide6 import QtCore
+from PySide6 import QtGui, QtWidgets
 
 from twisted.internet import threads
 from twisted.internet import reactor
 
 # sas-global
 from sas.sascalc.invariant import invariant
-from sas.qtgui.Plotting.PlotterData import Data1D
+from sas.qtgui.Plotting.PlotterData import Data1D, DataRole
 import sas.qtgui.Utilities.GuiUtils as GuiUtils
 
 # local
+from ..perspective import Perspective
 from .UI.TabbedInvariantUI import Ui_tabbedInvariantUI
 from .InvariantDetails import DetailsDialog
 from .InvariantUtils import WIDGETS
@@ -33,17 +34,25 @@ BG_WHITE = "background-color: rgb(255, 255, 255);"
 BG_RED = "background-color: rgb(244, 170, 164);"
 
 
-class InvariantWindow(QtWidgets.QDialog, Ui_tabbedInvariantUI):
+class InvariantWindow(QtWidgets.QDialog, Ui_tabbedInvariantUI, Perspective):
     # The controller which is responsible for managing signal slots connections
     # for the gui and providing an interface to the data model.
-    name = "Invariant"  # For displaying in the combo box in DataExplorer
-    ext = 'inv'  # File extension used for saving analyses
+
+
+    name = "Invariant"
+    ext = 'inv'
+
+    @property
+    def title(self):
+        """ Perspective name """
+        return "Invariant Perspective"
+
 
     def __init__(self, parent=None):
-        super(InvariantWindow, self).__init__()
+        super().__init__()
         self.setupUi(self)
 
-        self.setWindowTitle(self.title())
+        self.setWindowTitle(self.title)
 
         # initial input params
         self._background = 0.0
@@ -138,21 +147,21 @@ class InvariantWindow(QtWidgets.QDialog, Ui_tabbedInvariantUI):
 
         self.mapper.toFirst()
 
-    def get_low_q_extrapolation_upper_limit(self):
+    def get_low_q_extrapolation_upper_limit(self): # TODO: No usages
         q_value = self._data.x[int(self.txtNptsLowQ.text()) - 1]
         return q_value
 
-    def set_low_q_extrapolation_upper_limit(self, value):
+    def set_low_q_extrapolation_upper_limit(self, value): # TODO: No usages
         n_pts = (np.abs(self._data.x - value)).argmin() + 1
         item = QtGui.QStandardItem(str(n_pts))
         self.model.setItem(WIDGETS.W_NPTS_LOWQ, item)
         self.txtNptsLowQ.setText(str(n_pts))
 
-    def get_high_q_extrapolation_lower_limit(self):
+    def get_high_q_extrapolation_lower_limit(self): # TODO: No usgaes
         q_value = self._data.x[len(self._data.x) - int(self.txtNptsHighQ.text()) - 1]
         return q_value
 
-    def set_high_q_extrapolation_lower_limit(self, value):
+    def set_high_q_extrapolation_lower_limit(self, value): # TODO: No usages
         n_pts = len(self._data.x) - (np.abs(self._data.x - value)).argmin() + 1
         item = QtGui.QStandardItem(str(int(n_pts)))
         self.model.setItem(WIDGETS.W_NPTS_HIGHQ, item)
@@ -162,9 +171,9 @@ class InvariantWindow(QtWidgets.QDialog, Ui_tabbedInvariantUI):
         """ """
         self.cmdStatus.setEnabled(True)
 
-    def setClosable(self, value=True):
+    def setClosable(self, value: bool=True):
         """ Allow outsiders close this widget """
-        assert isinstance(value, bool)
+        assert isinstance(value, bool) # TODO: Remove
 
         self._allow_close = value
 
@@ -211,7 +220,7 @@ class InvariantWindow(QtWidgets.QDialog, Ui_tabbedInvariantUI):
         self._high_fit = str(self.model.item(WIDGETS.W_HIGHQ_FIT).text()) == 'true'
         self._high_power_value = float(self.model.item(WIDGETS.W_HIGHQ_POWER_VALUE).text())
 
-    def calculateInvariant(self):
+    def calculateInvariant(self): # TODO: pythonic name
         """ Use twisted to thread the calculations away """
         # Find out if extrapolation needs to be used.
         extrapolation = None
@@ -233,8 +242,8 @@ class InvariantWindow(QtWidgets.QDialog, Ui_tabbedInvariantUI):
         d.addCallback(self.deferredPlot)
         d.addErrback(self.calculationFailed)
 
-    def calculationFailed(self, reason):
-        print("calculation failed: ", reason)
+    def calculationFailed(self, reason): # TODO: rename to on_calculation_failed
+        print("calculation failed: ", reason) # TODO: Print to log
         self.allow_calculation()
 
     def deferredPlot(self, model):
@@ -249,7 +258,7 @@ class InvariantWindow(QtWidgets.QDialog, Ui_tabbedInvariantUI):
         self.cmdCalculate.setEnabled(True)
         self.cmdCalculate.setText("Calculate")
 
-    def plotResult(self, model):
+    def plotResult(self, model): # TODO: Pythonic name, typing
         """ Plot result of calculation """
 
         self.model = model
@@ -257,7 +266,7 @@ class InvariantWindow(QtWidgets.QDialog, Ui_tabbedInvariantUI):
         # Send the modified model item to DE for keeping in the model
         plots = [self._model_item]
         if self.high_extrapolation_plot:
-            self.high_extrapolation_plot.plot_role = Data1D.ROLE_DEFAULT
+            self.high_extrapolation_plot.plot_role = DataRole.ROLE_DEFAULT
             self.high_extrapolation_plot.symbol = "Line"
             self.high_extrapolation_plot.show_errors = False
             self.high_extrapolation_plot.show_q_range_sliders = True
@@ -271,7 +280,7 @@ class InvariantWindow(QtWidgets.QDialog, Ui_tabbedInvariantUI):
                                              self.high_extrapolation_plot.title)
             plots.append(self.high_extrapolation_plot)
         if self.low_extrapolation_plot:
-            self.low_extrapolation_plot.plot_role = Data1D.ROLE_DEFAULT
+            self.low_extrapolation_plot.plot_role = DataRole.ROLE_DEFAULT
             self.low_extrapolation_plot.symbol = "Line"
             self.low_extrapolation_plot.show_errors = False
             self.low_extrapolation_plot.show_q_range_sliders = True
@@ -290,14 +299,14 @@ class InvariantWindow(QtWidgets.QDialog, Ui_tabbedInvariantUI):
         # Update the details dialog in case it is open
         self.updateDetailsWidget(model)
 
-    def updateDetailsWidget(self, model):
+    def updateDetailsWidget(self, model): # TODO: pythonic name, type model
         """
         On demand update of the details widget
         """
         if self.detailsDialog.isVisible():
             self.onStatus()
 
-    def calculateThread(self, extrapolation):
+    def calculateThread(self, extrapolation): # Pythonic name, typing
         """
         Perform Invariant calculations.
         """
@@ -495,22 +504,18 @@ class InvariantWindow(QtWidgets.QDialog, Ui_tabbedInvariantUI):
 
         return self.model
 
-    def updateModelFromThread(self, widget, value):
+    def updateModelFromThread(self, widget, value): # TODO: Name, and typing
         """
         Update the model in the main thread
         """
         try:
-            value = float('%.3g' % value)
+            value = float('%.3g' % value) # TODO: Replace with round
         except TypeError:
             pass
         item = QtGui.QStandardItem(str(value))
         self.model.setItem(widget, item)
         self.mapper.toLast()
 
-    def title(self):
-        """ Perspective name """
-        return "Invariant Perspective"
-
     def onStatus(self):
         """
         Display Invariant Details panel when clicking on Status button
@@ -1026,7 +1031,7 @@ class InvariantWindow(QtWidgets.QDialog, Ui_tabbedInvariantUI):
             state[data_id] = {'invar_params': tab_data}
         return state
 
-    def getPage(self):
+    def getPage(self) -> dict: # TODO: Better name, serializePage, pageData
         """
         Serializes full state of this invariant page
         Called by Save Analysis
@@ -1039,7 +1044,7 @@ class InvariantWindow(QtWidgets.QDialog, Ui_tabbedInvariantUI):
             param_dict['data_id'] = str(self._data.id)
         return param_dict
 
-    def getState(self):
+    def getState(self): # TODO: Better name, serializeState, stateData
         """
         Collects all active params into a dictionary of {name: value}
         :return: {name: value}
