@@ -1,7 +1,7 @@
 import logging
 import numpy as np
 
-from PyQt5 import QtGui, QtCore, QtWidgets
+from PySide6 import QtGui, QtCore, QtWidgets
 
 # sas-global
 import sas.qtgui.Utilities.GuiUtils as GuiUtils
@@ -13,15 +13,16 @@ from .InversionLogic import InversionLogic
 
 # pr inversion calculation elements
 from sas.sascalc.pr.invertor import Invertor
-from sas.qtgui.Plotting.PlotterData import Data1D
+from sas.qtgui.Plotting.PlotterData import Data1D, DataRole
 # Batch calculation display
 from sas.qtgui.Utilities.GridPanel import BatchInversionOutputPanel
+from sas.qtgui.Perspectives.perspective import Perspective
 
-
-def is_float(value):
-    """Converts text input values to floats. Empty strings throw ValueError"""
+def str_to_float(string: str):
+    """Converts text input values to float.
+    Failure to parse string returns zero"""
     try:
-        return float(value)
+        return float(string)
     except ValueError:
         return 0.0
 
@@ -35,24 +36,30 @@ DICT_KEYS = ["Calculator", "PrPlot", "DataPlot"]
 logger = logging.getLogger(__name__)
 
 
-class InversionWindow(QtWidgets.QDialog, Ui_PrInversion):
+class InversionWindow(QtWidgets.QDialog, Ui_PrInversion, Perspective):
     """
     The main window for the P(r) Inversion perspective.
     """
 
     name = "Inversion"
-    ext = "pr"  # Extension used for saving analyses
-    estimateSignal = QtCore.pyqtSignal(tuple)
-    estimateNTSignal = QtCore.pyqtSignal(tuple)
-    estimateDynamicNTSignal = QtCore.pyqtSignal(tuple)
-    estimateDynamicSignal = QtCore.pyqtSignal(tuple)
-    calculateSignal = QtCore.pyqtSignal(tuple)
+    ext = "pr"
+
+    @property
+    def title(self) -> str:
+        """ Window title"""
+        return "P(r) Inversion Perspective"
+
+    estimateSignal = QtCore.Signal(tuple)
+    estimateNTSignal = QtCore.Signal(tuple)
+    estimateDynamicNTSignal = QtCore.Signal(tuple)
+    estimateDynamicSignal = QtCore.Signal(tuple)
+    calculateSignal = QtCore.Signal(tuple)
 
     def __init__(self, parent=None, data=None):
-        super(InversionWindow, self).__init__()
+        super().__init__()
         self.setupUi(self)
 
-        self.setWindowTitle("P(r) Inversion Perspective")
+        self.setWindowTitle(self.title)
 
         self._manager = parent
         #Needed for Batch fitting
@@ -201,15 +208,15 @@ class InversionWindow(QtWidgets.QDialog, Ui_PrInversion):
         self.backgroundInput.textChanged.connect(
             lambda: self.set_background(self.backgroundInput.text()))
         self.regularizationConstantInput.textChanged.connect(
-            lambda: self._calculator.set_alpha(is_float(self.regularizationConstantInput.text())))
+            lambda: self._calculator.set_alpha(str_to_float(self.regularizationConstantInput.text())))
         self.maxDistanceInput.textChanged.connect(
-            lambda: self._calculator.set_dmax(is_float(self.maxDistanceInput.text())))
+            lambda: self._calculator.set_dmax(str_to_float(self.maxDistanceInput.text())))
         self.maxQInput.editingFinished.connect(self.check_q_high)
         self.minQInput.editingFinished.connect(self.check_q_low)
         self.slitHeightInput.textChanged.connect(
-            lambda: self._calculator.set_slit_height(is_float(self.slitHeightInput.text())))
+            lambda: self._calculator.set_slit_height(str_to_float(self.slitHeightInput.text())))
         self.slitWidthInput.textChanged.connect(
-            lambda: self._calculator.set_slit_width(is_float(self.slitWidthInput.text())))
+            lambda: self._calculator.set_slit_width(str_to_float(self.slitWidthInput.text())))
 
         self.model.itemChanged.connect(self.model_changed)
         self.estimateNTSignal.connect(self._estimateNTUpdate)
@@ -432,7 +439,7 @@ class InversionWindow(QtWidgets.QDialog, Ui_PrInversion):
         """
         if self.batchResultsWindow is None:
             self.batchResultsWindow = BatchInversionOutputPanel(
-                parent=self, output_data=self.batchResults)
+                parent=self._parent, output_data=self.batchResults)
         else:
             self.batchResultsWindow.setupTable(self.batchResults)
         self.batchResultsWindow.show()
@@ -516,12 +523,12 @@ class InversionWindow(QtWidgets.QDialog, Ui_PrInversion):
                 self.logic.add_errors()
             self.updateDataList(data)
             self.populateDataComboBox(self.logic.data.name, data)
-        self.dataList.setCurrentIndex(len(self.dataList) - 1)
+        self.dataList.setCurrentIndex(self.dataList.count() - 1)
         #Checking for 1D again to mitigate the case when 2D data is last on the data list
         if isinstance(self.logic.data, Data1D):
             self.setCurrentData(data)
 
-    def updateDataList(self, dataRef):
+    def updateDataList(self, dataRef): # TODO Typing, name, underscore prefix
         """Save the current data state of the window into self._data_list"""
         if dataRef is None:
             return
@@ -647,12 +654,12 @@ class InversionWindow(QtWidgets.QDialog, Ui_PrInversion):
                                            pr.get_pos_err(out, cov))))
         if self.prPlot is not None:
             title = self.prPlot.name
-            self.prPlot.plot_role = Data1D.ROLE_RESIDUAL
+            self.prPlot.plot_role = DataRole.ROLE_STAND_ALONE
             GuiUtils.updateModelItemWithPlot(self._data, self.prPlot, title)
             self.communicate.plotRequestedSignal.emit([self._data,self.prPlot], None)
         if self.dataPlot is not None:
             title = self.dataPlot.name
-            self.dataPlot.plot_role = Data1D.ROLE_DEFAULT
+            self.dataPlot.plot_role = DataRole.ROLE_DEFAULT
             self.dataPlot.symbol = "Line"
             self.dataPlot.show_errors = False
             GuiUtils.updateModelItemWithPlot(self._data, self.dataPlot, title)
@@ -675,12 +682,13 @@ class InversionWindow(QtWidgets.QDialog, Ui_PrInversion):
             self.dataPlot.slider_low_q_setter = []
             self.dataPlot.slider_high_q_setter = []
         self._data = None
-        length = len(self.dataList)
+        length = self.dataList.count()
         for index in reversed(range(length)):
             if self.dataList.itemData(index) in data_list:
                 self.dataList.removeItem(index)
         # Last file removed
         self.dataDeleted = False
+        # if self._dataList.count() == 0:
         if len(self._dataList) == 0:
             self.prPlot = None
             self.dataPlot = None
@@ -692,10 +700,16 @@ class InversionWindow(QtWidgets.QDialog, Ui_PrInversion):
                 self.nTermsSuggested))
             self.regConstantSuggestionButton.setText("{:-3.2g}".format(
                 REGULARIZATION))
-            self.updateGuiValues()
             self.setupModel()
+            self.enableButtons()
         else:
+            # Block the signal, otherwise self.displayChange, triggered by a change to self.dataList, will run in
+            #  parallel with self.updateGuiValues. If self.displayChange is not finished before self.updateGuiValues
+            #  is launched, plots that have been deleted may still get called, throwing AttributeErrors.
+            self.dataList.blockSignals(True)
             self.dataList.setCurrentIndex(0)
+            self.displayChange(0)
+            self.dataList.blockSignals(False)
             self.updateGuiValues()
 
     def serializeAll(self):
