@@ -4,24 +4,29 @@ All its variables are bound to the module,
 which can not be instantiated repeatedly so IDs are session-specific.
 """
 import sys
+import weakref
+
+# TODO Refactor to allow typing without circular import
+#from sas.qtgui.Plotting.PlotterBase import PlotterBase
 
 this = sys.modules[__name__]
 
-this._plots = {}
+this._plots = weakref.WeakValueDictionary()
 this._plot_id = 0
 
 def clear():
     """
     Reset the plot dictionary
     """
-    this._plots = {}
+    this._plots = weakref.WeakValueDictionary()
 
+#def addPlot(plot: PlotterBase):
 def addPlot(plot):
     """
     Adds a new plot to the current dictionary of plots
     """
     this._plot_id += 1
-    this._plots["Graph%s"%str(this._plot_id)] = plot
+    this._plots["Graph%s"%str(this._plot_id)] = plot # TODO: Why???
 
 def deletePlot(plot_id):
     """
@@ -30,7 +35,7 @@ def deletePlot(plot_id):
     if plot_id in this._plots:
         del this._plots[plot_id]
 
-def currentPlots():
+def currentPlotIds():
     """
     Returns a list of IDs for all currently active plots
     """
