@@ -1,5 +1,5 @@
-from PyQt5 import QtCore
-from PyQt5 import QtWidgets
+from PySide6 import QtCore
+from PySide6 import QtWidgets
 
 from sas.qtgui.Plotting.PlotUtilities import COLORS, SHAPES
 from sas.qtgui.Plotting.UI.PlotPropertiesUI import Ui_PlotPropertiesUI
@@ -14,8 +14,6 @@ class PlotProperties(QtWidgets.QDialog, Ui_PlotPropertiesUI):
                  legend=""):
         super(PlotProperties, self).__init__(parent)
         self.setupUi(self)
-        # disable the context help icon
-        self.setWindowFlags(self.windowFlags() & ~QtCore.Qt.WindowContextHelpButtonHint)
 
         self.setFixedSize(self.minimumSizeHint())
 
@@ -90,7 +88,7 @@ class PlotProperties(QtWidgets.QDialog, Ui_PlotPropertiesUI):
             # Save the color as #RRGGBB
             self.custom_color = True
             self._color = str(proposed_color.name())
-   
+
     def onColorIndexChange(self):
         """
         Dynamically add/remove "Custom" color index
@@ -100,4 +98,3 @@ class PlotProperties(QtWidgets.QDialog, Ui_PlotPropertiesUI):
         self.custom_color = False
         if custom_index > -1:
             self.cbColor.removeItem(custom_index)
-        
\ No newline at end of file
