@@ -179,12 +179,8 @@ class PlotterWidget(PlotterBase):
         markersize = data.markersize
 
         # Include scaling (log vs. linear)
-        if version.parse(mpl.__version__) < version.parse("3.3"):
-            ax.set_xscale(self.xscale, nonposx='clip') if self.xscale != 'linear' else self.ax.set_xscale(self.xscale)
-            ax.set_yscale(self.yscale, nonposy='clip') if self.yscale != 'linear' else self.ax.set_yscale(self.yscale)
-        else:
-            ax.set_xscale(self.xscale, nonpositive='clip') if self.xscale != 'linear' else self.ax.set_xscale(self.xscale)
-            ax.set_yscale(self.yscale, nonpositive='clip') if self.yscale != 'linear' else self.ax.set_yscale(self.yscale)
+        ax.set_xscale(self.xscale, nonpositive='clip') if self.xscale != 'linear' else self.ax.set_xscale(self.xscale)
+        ax.set_yscale(self.yscale, nonpositive='clip') if self.yscale != 'linear' else self.ax.set_yscale(self.yscale)
 
         # Draw non-standard markers
         l_width = markersize * 0.4
@@ -231,7 +227,7 @@ class PlotterWidget(PlotterBase):
             ax.axhline(color='black', linewidth=1)
 
         # Display +/- 3 sigma and +/- 1 sigma lines for residual plots
-        if data.plot_role == DataRole.ROLE_RESIDUAL:
+        if data.plot_role in [DataRole.ROLE_RESIDUAL, DataRole.ROLE_RESIDUAL_SESANS]:
             ax.axhline(y=3, color='red', linestyle='-')
             ax.axhline(y=-3, color='red', linestyle='-')
             ax.axhline(y=1, color='gray', linestyle='--')
@@ -338,13 +334,12 @@ class PlotterWidget(PlotterBase):
         :returns:
         """
 
-
         x_min, x_max = np.inf, -np.inf
         y_min, y_max = np.inf, -np.inf
 
         for key in self.plot_dict:
 
-            plot_data = self.plot_dict[key]
+            plot_data = self.plot_dict[key].view
 
             if len(plot_data.x) > 0:
                 x_min = min(np.min(plot_data.x), x_min)
@@ -352,7 +347,7 @@ class PlotterWidget(PlotterBase):
 
             if len(plot_data.y) > 0:
 
-                dy = plot_data.view.dy
+                dy = plot_data.dy
                 if dy is None:
                     y_min = min(np.min(plot_data.y), y_min)
                     y_max = max(np.max(plot_data.y), y_max)
@@ -677,14 +672,13 @@ class PlotterWidget(PlotterBase):
     def replacePlot(self, id, new_plot, retain_dimensions=True):
         """
         Remove plot 'id' and add 'new_plot' to the chart.
-        This effectlvely refreshes the chart with changes to one of its plots
+        This effectively refreshes the chart with changes to one of its plots
         """
 
         # Pull the current transform settings from the old plot
         selected_plot = self.plot_dict[id]
-        new_plot.xtransform = selected_plot.xtransform
-        new_plot.ytransform = selected_plot.ytransform
-        #Adding few properties ftom ModifyPlot to preserve them in future changes
+        new_plot.plot_role = selected_plot.plot_role
+        # Adding few properties from ModifyPlot to preserve them in future changes
         new_plot.title = selected_plot.title
         new_plot.custom_color = selected_plot.custom_color
         new_plot.markersize = selected_plot.markersize
@@ -827,17 +821,15 @@ class PlotterWidget(PlotterBase):
 
         pass # debug hook
 
-    def onFitDisplay(self, fit_data):
+    def onFitDisplay(self, temp_x, temp_y):
         """
         Add a linear fitting line to the chart
         """
         # Create new data structure with fitting result
-        tempx = fit_data[0]
-        tempy = fit_data[1]
         self.fit_result.x = []
         self.fit_result.y = []
-        self.fit_result.x = tempx
-        self.fit_result.y = tempy
+        self.fit_result.x = temp_x
+        self.fit_result.y = temp_y
         self.fit_result.dx = None
         self.fit_result.dy = None
 
@@ -906,12 +898,12 @@ class PlotterWidget(PlotterBase):
             # self.ax.tick_params(axis='x', labelsize=fx.size, labelcolor=fx.color)
             from matplotlib.pyplot import gca
             a = gca()
-            a.set_xticklabels(a.get_xticks(), fx)
+            a.set_xticklabels(a.get_xticks(), **fx)
         if apply_y:
             # self.ay.tick_params(axis='y', labelsize=fy.size, labelcolor=fy.color)
             from matplotlib.pyplot import gca
             a = gca()
-            a.set_yticklabels(a.get_yticks(), fy)
+            a.set_yticklabels(a.get_yticks(), **fy)
         self.canvas.draw_idle()
 
     def onMplMouseDown(self, event):
