@@ -2,12 +2,12 @@ import copy
 import numpy
 import functools
 
-from PyQt5 import QtGui
-from PyQt5 import QtWidgets
+from PySide6 import QtGui
+from PySide6 import QtWidgets
 
 from mpl_toolkits.mplot3d import Axes3D
 
-from sas.sascalc.dataloader.manipulations import CircularAverage
+from sasdata.data_util.manipulations import CircularAverage
 
 from sas.qtgui.Plotting.PlotterData import Data1D
 from sas.qtgui.Plotting.PlotterData import Data2D
@@ -19,9 +19,10 @@ from sas.qtgui.Plotting.ColorMap import ColorMap
 from sas.qtgui.Plotting.BoxSum import BoxSum
 from sas.qtgui.Plotting.SlicerParameters import SlicerParameters
 
-# TODO: move to sas.qtgui namespace
 from sas.qtgui.Plotting.Slicers.BoxSlicer import BoxInteractorX
 from sas.qtgui.Plotting.Slicers.BoxSlicer import BoxInteractorY
+from sas.qtgui.Plotting.Slicers.WedgeSlicer import WedgeInteractorQ
+from sas.qtgui.Plotting.Slicers.WedgeSlicer import WedgeInteractorPhi
 from sas.qtgui.Plotting.Slicers.AnnulusSlicer import AnnulusInteractor
 from sas.qtgui.Plotting.Slicers.SectorSlicer import SectorInteractor
 from sas.qtgui.Plotting.Slicers.BoxSum import BoxSumCalculator
@@ -39,7 +40,7 @@ class Plotter2DWidget(PlotterBase):
     """
     def __init__(self, parent=None, manager=None, quickplot=False, dimension=2):
         self.dimension = dimension
-        super(Plotter2DWidget, self).__init__(parent, manager=manager, quickplot=quickplot)
+        super(Plotter2DWidget, self).__init__(manager=manager, quickplot=quickplot)
 
         self.cmap = DEFAULT_CMAP.name
         # Default scale
@@ -52,6 +53,10 @@ class Plotter2DWidget(PlotterBase):
         self.vmin = None
         self.vmax = None
         self.im = None
+        self.cb = None
+        # Masking properties
+        self._show_masked_data = False  # TODO: Tie into configuration system
+        self._masked_data = []
 
         self.manager = manager
 
@@ -61,15 +66,35 @@ class Plotter2DWidget(PlotterBase):
 
     @property
     def data0(self):
-        return self._data[0]
+        return self._data[0] if not self._show_masked_data else self._masked_data[0]
 
     @data.setter
     def data(self, data=None):
         """ data setter """
+        if hasattr(data, 'mask') and not data.mask.all():
+            # Create a copy of the data set to only be used in this context
+            # Remove all masked points from the copy
+            masked_data = copy.deepcopy(data)
+            masked_data.data = masked_data.data[masked_data.mask == 1]
+            masked_data.qx_data = masked_data.qx_data[masked_data.mask == 1]
+            masked_data.qy_data = masked_data.qy_data[masked_data.mask == 1]
+            if masked_data.err_data is not None:
+                masked_data.err_data = masked_data.err_data[masked_data.mask == 1]
+            if masked_data.dqx_data is not None:
+                masked_data.dqx_data = masked_data.dqx_data[masked_data.mask == 1]
+            if masked_data.dqy_data is not None:
+                masked_data.dqy_data = masked_data.dqy_data[masked_data.mask == 1]
+            if masked_data.q_data is not None:
+                masked_data.q_data = masked_data.q_data[masked_data.mask == 1]
+            masked_data.mask = masked_data.mask[masked_data.mask == 1]
+        else:
+            masked_data = data
         if self._data:
             self._data[0] = data
+            self._masked_data[0] = masked_data
         else:
             self._data.append(data)
+            self._masked_data.append(masked_data)
         self.qx_data = data.qx_data
         self.qy_data = data.qy_data
         self.xmin = data.xmin
@@ -101,8 +126,8 @@ class Plotter2DWidget(PlotterBase):
 
         # Prepare and show the plot
         self.showPlot(data=self.data0.data,
-                      qx_data=self.qx_data,
-                      qy_data=self.qy_data,
+                      qx_data=self.data0.qx_data,
+                      qy_data=self.data0.qy_data,
                       xmin=self.xmin,
                       xmax=self.xmax,
                       ymin=self.ymin, ymax=self.ymax,
@@ -111,6 +136,7 @@ class Plotter2DWidget(PlotterBase):
                       update=update)
 
         self.updateCircularAverage()
+        self.updateSlicer()
 
     def calculateDepth(self):
         """
@@ -140,7 +166,35 @@ class Plotter2DWidget(PlotterBase):
         """
         Define common context menu and associated actions for the MPL widget
         """
+                
         self.defaultContextMenu()
+        
+        plot_slicer_menu=self.contextMenu.addMenu('Slicers')
+        self.actionCircularAverage = plot_slicer_menu.addAction("&Perform Circular Average")
+        self.actionCircularAverage.triggered.connect(self.onCircularAverage)
+        self.actionSectorView = plot_slicer_menu.addAction("&Sector [Q View]")
+        self.actionSectorView.triggered.connect(self.onSectorView)
+        self.actionAnnulusView = plot_slicer_menu.addAction("&Annulus [Phi View]")
+        self.actionAnnulusView.triggered.connect(self.onAnnulusView)
+        self.actionBoxSum = plot_slicer_menu.addAction("&Box Sum")
+        self.actionBoxSum.triggered.connect(self.onBoxSum)
+        self.actionBoxAveragingX = plot_slicer_menu.addAction("&Box Averaging in Qx")
+        self.actionBoxAveragingX.triggered.connect(self.onBoxAveragingX)
+        self.actionBoxAveragingY = plot_slicer_menu.addAction("&Box Averaging in Qy")
+        self.actionBoxAveragingY.triggered.connect(self.onBoxAveragingY)
+        self.actionWedgeAveragingQ = plot_slicer_menu.addAction("&Wedge Averaging in Q")
+        self.actionWedgeAveragingQ.triggered.connect(self.onWedgeAveragingQ)
+        self.actionWedgeAveragingPhi = plot_slicer_menu.addAction("&Wedge Averaging in Phi")
+        self.actionWedgeAveragingPhi.triggered.connect(self.onWedgeAveragingPhi)
+
+        plot_slicer_menu.addSeparator()
+
+        # Additional items for slicer interaction
+        if self.slicer:
+            plot_slicer_menu.actionClearSlicer = plot_slicer_menu.addAction("&Clear Slicer")
+            plot_slicer_menu.actionClearSlicer.triggered.connect(self.onClearSlicer)
+        plot_slicer_menu.actionEditSlicer = plot_slicer_menu.addAction("&Edit Slicer Parameters")
+        plot_slicer_menu.actionEditSlicer.triggered.connect(self.onEditSlicer)
 
         self.contextMenu.addSeparator()
         self.actionDataInfo = self.contextMenu.addAction("&DataInfo")
@@ -152,29 +206,14 @@ class Plotter2DWidget(PlotterBase):
              functools.partial(self.onSavePoints, self.data0))
         self.contextMenu.addSeparator()
 
-        self.actionCircularAverage = self.contextMenu.addAction("&Perform Circular Average")
-        self.actionCircularAverage.triggered.connect(self.onCircularAverage)
-
-        self.actionSectorView = self.contextMenu.addAction("&Sector [Q View]")
-        self.actionSectorView.triggered.connect(self.onSectorView)
-        self.actionAnnulusView = self.contextMenu.addAction("&Annulus [Phi View]")
-        self.actionAnnulusView.triggered.connect(self.onAnnulusView)
-        self.actionBoxSum = self.contextMenu.addAction("&Box Sum")
-        self.actionBoxSum.triggered.connect(self.onBoxSum)
-        self.actionBoxAveragingX = self.contextMenu.addAction("&Box Averaging in Qx")
-        self.actionBoxAveragingX.triggered.connect(self.onBoxAveragingX)
-        self.actionBoxAveragingY = self.contextMenu.addAction("&Box Averaging in Qy")
-        self.actionBoxAveragingY.triggered.connect(self.onBoxAveragingY)
         # Additional items for slicer interaction
-        if self.slicer:
-            self.actionClearSlicer = self.contextMenu.addAction("&Clear Slicer")
-            self.actionClearSlicer.triggered.connect(self.onClearSlicer)
-        self.actionEditSlicer = self.contextMenu.addAction("&Edit Slicer Parameters")
-        self.actionEditSlicer.triggered.connect(self.onEditSlicer)
         self.contextMenu.addSeparator()
         self.actionColorMap = self.contextMenu.addAction("&2D Color Map")
         self.actionColorMap.triggered.connect(self.onColorMap)
         self.contextMenu.addSeparator()
+        self.actionToggleMaskedData = self.contextMenu.addAction("&Toggle Masked Data")
+        self.actionToggleMaskedData.triggered.connect(self.onToggleMaskedData)
+        self.contextMenu.addSeparator()
         self.actionChangeScale = self.contextMenu.addAction("Toggle Linear/Log Scale")
         self.actionChangeScale.triggered.connect(self.onToggleScale)
         self.contextMenu.addSeparator()
@@ -197,6 +236,11 @@ class Plotter2DWidget(PlotterBase):
         if self.dimension == 2:
             self.actionToggleGrid.triggered.connect(self.onGridToggle)
 
+    def onToggleMaskedData(self, event):
+        """ Toggle the visibility of masked data points."""
+        self._show_masked_data = not self._show_masked_data
+        self.plot()
+
     def onToggleScale(self, event):
         """
         Toggle axis and replot image
@@ -295,8 +339,7 @@ class Plotter2DWidget(PlotterBase):
         else:
             new_plot.yaxis("\\rm{Intensity} ", "cm^{-1}")
 
-        new_plot.group_id = "2daverage" + self.data0.name
-        new_plot.id = "Circ avg " + self.data0.name
+        new_plot.id = "2daverage" + self.data0.name
         new_plot.is_data = True
 
         return new_plot
@@ -332,8 +375,8 @@ class Plotter2DWidget(PlotterBase):
         # See if current item plots contain 2D average plot
         has_plot = False
         for plot in plots:
-            if plot.group_id is None: continue
-            if ca_caption in plot.group_id: has_plot = True
+            if plot.id is None: continue
+            if ca_caption in plot.id: has_plot = True
         # return prematurely if no circular average plot found
         if not has_plot: return
 
@@ -345,6 +388,32 @@ class Plotter2DWidget(PlotterBase):
         # Show the new plot, if already visible
         self.manager.communicator.plotUpdateSignal.emit([new_plot])
 
+    def updateSlicer(self):
+        """
+        Update slicer plot on Data2D change
+        """
+        if not hasattr(self, '_item'): return
+        item = self._item
+        if self._item.parent() is not None:
+            item = self._item.parent()
+
+        # Get all plots for current item
+        plots = GuiUtils.plotsFromModel("", item)
+        if plots is None: return
+        slicer_caption = 'Slicer' + self.data0.name
+        # See if current item plots contain slicer plot
+        has_plot = False
+        for plot in plots:
+            if not hasattr(plot, 'type_id') or plot.type_id is None: continue
+            if slicer_caption in plot.type_id: has_plot = True
+        # return prematurely if no slicer plot found
+        if not has_plot: return
+
+        # Now that we've identified the right plot, update the 2D data the slicer uses
+        self.slicer.data = self.data0
+        # Replot now that the 2D data is updated
+        self.slicer._post_data()
+
     def setSlicer(self, slicer, reset=True):
         """
         Clear the previous slicer and create a new one.
@@ -353,6 +422,65 @@ class Plotter2DWidget(PlotterBase):
         # Clear current slicer
         if self.slicer is not None:
             self.slicer.clear()
+
+        # Clear the old slicer plots so they don't reappear later
+        if hasattr(self, '_item'):
+            item = self._item
+            if self._item.parent() is not None:
+                item = self._item.parent()
+
+            # Go through all items and see if they are a plot. The checks done here are not as thorough
+            # as GuiUtils.deleteRedundantPlots (which this takes a lot from). Will this cause problems?
+            # Primary concern is the check (plot_data.plot_role == DataRole.ROLE_DELETABLE) as I don't
+            # know what it does. The other checks seem to be related to keeping the new plots for that function
+            # TODO: generalize this and put it in GuiUtils so that we can use it elsewhere
+            tempPlotsToRemove = []
+            slicer_type_id = 'Slicer' + self.data0.name
+            for itemIndex in range(item.rowCount()):
+                # GuiUtils.plotsFromModel tests if the data is of type Data1D or Data2D to determine
+                # if it is a plot, so let's try that
+                if isinstance(item.child(itemIndex).data(), (Data1D, Data2D)):
+                    # First take care of this item, then we'll take care of its children
+                    if hasattr(item.child(itemIndex).data(), 'type_id'):
+                        if slicer_type_id in item.child(itemIndex).data().type_id:
+                            # At the time of writing, this should never be the case, but at some point the slicers may
+                            # have relevant children (e.g. plots). We don't want to delete these slicers.
+                            tempHasImportantChildren = False
+                            for tempChildCheck in range(item.child(itemIndex).rowCount()):
+                                # The data explorer uses the "text" attribute to set the name. If this has text='' then
+                                # it can be deleted.
+                                if item.child(itemIndex).child(tempChildCheck).text():
+                                    tempHasImportantChildren = True
+                            if not tempHasImportantChildren:
+                                # Store this plot to be removed later. Removing now
+                                # will cause the next plot to be skipped
+                                tempPlotsToRemove.append(item.child(itemIndex))
+                # It looks like the slicers are children of items that do not have data of instance Data1D or Data2D.
+                # Now do the children (1 level deep as is done in GuiUtils.plotsFromModel). Note that the slicers always
+                # seem to be the first entry (index2 == 0)
+                for itemIndex2 in range(item.child(itemIndex).rowCount()):
+                    # Repeat what we did above (these if statements could probably be combined
+                    # into one, but I'm not confident enough with how these work to say it wouldn't
+                    # have issues if combined)
+                    if isinstance(item.child(itemIndex).child(itemIndex2).data(), (Data1D, Data2D)):
+                        if hasattr(item.child(itemIndex).child(itemIndex2).data(), 'type_id'):
+                            if slicer_type_id in item.child(itemIndex).child(itemIndex2).data().type_id:
+                                # Check for children we might want to keep (see the above loop)
+                                tempHasImportantChildren = False
+                                for tempChildCheck in range(item.child(itemIndex).child(itemIndex2).rowCount()):
+                                    # The data explorer uses the "text" attribute to set the name. If this has text=''
+                                    # then it can be deleted.
+                                    if item.child(itemIndex).child(itemIndex2).child(tempChildCheck).text():
+                                        tempHasImportantChildren = True
+                                if not tempHasImportantChildren:
+                                    # Remove the parent since each slicer seems to generate a new entry in item
+                                    tempPlotsToRemove.append(item.child(itemIndex))
+            # Remove all the parent plots with matching criteria
+            for plot in tempPlotsToRemove:
+                item.removeRow(plot.row())
+            # Delete the temporary list of plots to remove
+            del tempPlotsToRemove
+
         # Create a new slicer
         self.slicer_z += 1
         self.slicer = slicer(self, self.ax, item=self._item, zorder=self.slicer_z)
@@ -424,6 +552,20 @@ class Plotter2DWidget(PlotterBase):
         """
         self.setSlicer(slicer=BoxInteractorY)
 
+    def onWedgeAveragingQ(self):
+        """
+        Perform 2D data averaging on Q
+        Create a new slicer .
+        """
+        self.setSlicer(slicer=WedgeInteractorQ)
+
+    def onWedgeAveragingPhi(self):
+        """
+        Perform 2D data averaging on Phi
+        Create a new slicer .
+        """
+        self.setSlicer(slicer=WedgeInteractorPhi)
+
     def onColorMap(self):
         """
         Display the color map dialog and modify the plot's map accordingly
@@ -523,6 +665,7 @@ class Plotter2DWidget(PlotterBase):
                                 extent=(self.xmin, self.xmax,
                                         self.ymin, self.ymax))
 
+            # color bar for the plot
             cbax = self.figure.add_axes([0.88, 0.2, 0.02, 0.7])
 
             # Current labels for axes
@@ -533,20 +676,23 @@ class Plotter2DWidget(PlotterBase):
             if not self.quickplot:
                 self.ax.set_title(label=self._title)
 
+            # remove color bar in case we have it on screen
+            if self.cb is not None:
+                self.cb.remove()
             if cbax is None:
                 self.ax.set_frame_on(False)
-                cb = self.figure.colorbar(self.im, shrink=0.8, aspect=20)
+                self.cb = self.figure.colorbar(self.im, shrink=0.8, aspect=20)
             else:
-                cb = self.figure.colorbar(self.im, cax=cbax)
+                self.cb = self.figure.colorbar(self.im, cax=cbax)
 
-            cb.update_bruteforce(self.im)
-            cb.set_label('$' + self.scale + '$')
+            self.cb.update_normal(self.im)
+            self.cb.set_label('$' + self.scale + '$')
 
-            self.vmin = cb.vmin
-            self.vmax = cb.vmax
+            self.vmin = self.cb.vmin
+            self.vmax = self.cb.vmax
 
             if show_colorbar is False:
-                cb.remove()
+                self.cb.remove()
 
         else:
             # clear the previous 2D from memory
@@ -620,7 +766,6 @@ class Plotter2D(QtWidgets.QDialog, Plotter2DWidget):
     Plotter widget implementation
     """
     def __init__(self, parent=None, quickplot=False, dimension=2):
-        QtWidgets.QDialog.__init__(self)
         Plotter2DWidget.__init__(self, manager=parent, quickplot=quickplot, dimension=dimension)
         icon = QtGui.QIcon()
         icon.addPixmap(QtGui.QPixmap(":/res/ball.ico"), QtGui.QIcon.Normal, QtGui.QIcon.Off)
