@@ -4,7 +4,7 @@ Adapters for fitting module
 import copy
 import numpy
 import math
-from enum import Enum
+from enum import Enum, auto
 
 from sasdata.data_util.uncertainty import Uncertainty
 
@@ -18,17 +18,23 @@ from sasdata.dataloader.data_info import Data2D as LoadData2D
 class DataRole(Enum):
     """Labels to apply to different plot types."""
     # Data is for imported data
-    ROLE_DATA = 0
+    ROLE_DATA = auto()
     # Default is for fits of the imported data
-    ROLE_DEFAULT = 1
+    ROLE_DEFAULT = auto()
     # Deletable is for orphaned plots
-    ROLE_DELETABLE = 2
+    ROLE_DELETABLE = auto()
     # Residual is for stand-alone residual plots
-    ROLE_RESIDUAL = 3
+    ROLE_RESIDUAL = auto()
+    # Residual sesans is for stand-alone sesans residual plots
+    ROLE_RESIDUAL_SESANS = auto()
     # Stand alone is for plots that should be plotted separately
-    ROLE_STAND_ALONE = 4
-    # Polydispersity is for stand-alone polydispersity plot
-    ROLE_POLYDISPERSITY = 5
+    ROLE_STAND_ALONE = auto()
+    # LIN_LIN is for stand-alone plots on a linear-linear scale
+    ROLE_LIN_LIN = auto()
+    # POLYDISPERSITY role is to tag polydispersity plots to be able to suppress auto displaying them
+    ROLE_POLYDISPERSITY = auto()
+    # ANGULAR_SLICE role is to ensure angular slices from 2D plots are on linear scale
+    ROLE_ANGULAR_SLICE = auto()
 
 
 class Data1D(PlottableData1D, LoadData1D):
