@@ -1,6 +1,3 @@
-"""
-    Sector interactor
-"""
 import numpy
 import logging
 
@@ -13,7 +10,21 @@ MIN_PHI = 0.05
 
 class SectorInteractor(BaseInteractor, SlicerModel):
     """
-    Draw a sector slicer.Allow to performQ averaging on data 2D
+    SectorInteractor plots a data1D average of a sector area defined in a
+    Data2D object. The data1D averaging itself is performed in sasdata by
+    manipulations.py. Sectors all go through a single point as (0,0).
+
+    This class uses two other classes, LineInteractor and SideInteractor, to
+    define a sector centered around a main line defined by LineInteractor
+    which goes through 0,0 at some user settable angle theta from 0. The
+    sector itself is defined by the right and left sidelines, both of which
+    also go through (0,0), and set by SideInteractor from -phi to +phi around
+    the center line defined by the main line. All points at a constant Q from
+    -phi to +phi are averaged together to provide a 1D array in Q (to be
+    plotted as a function of Q).
+
+        ..TODO: the 2 subclasses here are the same as used by the BoxSum. These
+            should probably be abstracted out.
     """
     def __init__(self, base, axes, item=None, color='black', zorder=3):
 
@@ -48,15 +59,19 @@ class SectorInteractor(BaseInteractor, SlicerModel):
         self.right_line = SideInteractor(self, self.axes, color='black',
                                          zorder=zorder, r=self.qmax,
                                          phi=-1 * self.phi, theta2=self.theta2)
+        self.right_line.update(right=True)
         self.right_line.qmax = self.qmax
         # Left Side line
         self.left_line = SideInteractor(self, self.axes, color='black',
                                         zorder=zorder, r=self.qmax,
                                         phi=self.phi, theta2=self.theta2)
+        self.left_line.update(left=True)
         self.left_line.qmax = self.qmax
+        self.fold = True
         # draw the sector
         self.update()
         self._post_data()
+        self.draw()
         self.setModelFromParams()
 
     def set_layer(self, n):
@@ -89,24 +104,23 @@ class SectorInteractor(BaseInteractor, SlicerModel):
         if self.main_line.has_move:
             self.main_line.update()
             self.right_line.update(delta=-self.left_line.phi / 2,
-                                   mline=self.main_line.theta)
+                                   mline=self.main_line.theta, right=True)
             self.left_line.update(delta=self.left_line.phi / 2,
-                                  mline=self.main_line.theta)
+                                  mline=self.main_line.theta, left=True)
         # Check if the left side has moved and update the slicer accordingly
         if self.left_line.has_move:
             self.main_line.update()
             self.left_line.update(phi=None, delta=None, mline=self.main_line,
                                   side=True, left=True)
             self.right_line.update(phi=self.left_line.phi, delta=None,
-                                   mline=self.main_line, side=True,
-                                   left=False, right=True)
+                                   mline=self.main_line, side=True, right=True)
         # Check if the right side line has moved and update the slicer accordingly
         if self.right_line.has_move:
             self.main_line.update()
             self.right_line.update(phi=None, delta=None, mline=self.main_line,
-                                   side=True, left=False, right=True)
+                                   side=True, right=True)
             self.left_line.update(phi=self.right_line.phi, delta=None,
-                                  mline=self.main_line, side=True, left=False)
+                                  mline=self.main_line, side=True, left=True)
 
     def save(self, ev):
         """
@@ -128,7 +142,7 @@ class SectorInteractor(BaseInteractor, SlicerModel):
         if data is None:
             return
         # Averaging
-        from sas.sascalc.dataloader.manipulations import SectorQ
+        from sasdata.data_util.manipulations import SectorQ
         radius = self.qmax
         phimin = -self.left_line.phi + self.main_line.theta
         phimax = self.left_line.phi + self.main_line.theta
@@ -138,6 +152,7 @@ class SectorInteractor(BaseInteractor, SlicerModel):
                        phi_min=phimin + numpy.pi,
                        phi_max=phimax + numpy.pi, nbins=nbins)
 
+        sect.fold = self.fold
         sector = sect(self.data)
         # Create 1D data resulting from average
 
@@ -165,8 +180,8 @@ class SectorInteractor(BaseInteractor, SlicerModel):
             new_plot.ytransform = 'y'
             new_plot.yaxis("\\rm{Residuals} ", "/")
 
-        new_plot.group_id = "2daverage" + self.data.name
         new_plot.id = "SectorQ" + self.data.name
+        new_plot.type_id = "Slicer" + self.data.name # Used to remove plots after changing slicer so they don't keep showing up after closed
         new_plot.is_data = True
         item = self._item
         if self._item.parent() is not None:
@@ -178,7 +193,6 @@ class SectorInteractor(BaseInteractor, SlicerModel):
 
         if self.update_model:
             self.setModelFromParams()
-        self.draw()
 
     def validate(self, param_name, param_value):
         """
@@ -206,13 +220,13 @@ class SectorInteractor(BaseInteractor, SlicerModel):
         # Post parameters
         self._post_data(self.nbins)
 
-    def restore(self):
+    def restore(self, ev):
         """
         Restore the roughness for this layer.
         """
-        self.main_line.restore()
-        self.left_line.restore()
-        self.right_line.restore()
+        self.main_line.restore(ev)
+        self.left_line.restore(ev)
+        self.right_line.restore(ev)
 
     def move(self, x, y, ev):
         """
@@ -238,6 +252,7 @@ class SectorInteractor(BaseInteractor, SlicerModel):
         params["Phi [deg]"] = self.main_line.theta * 180 / numpy.pi
         params["Delta_Phi [deg]"] = numpy.fabs(self.left_line.phi * 180 / numpy.pi)
         params["nbins"] = self.nbins
+        params["fold"] = self.fold
         return params
 
     def setParams(self, params):
@@ -257,15 +272,17 @@ class SectorInteractor(BaseInteractor, SlicerModel):
             params["Delta_Phi [deg]"] = MIN_PHI
 
         self.nbins = int(params["nbins"])
+        self.fold =params["fold"]
         self.main_line.theta = main
         # Reset the slicer parameters
         self.main_line.update()
         self.right_line.update(phi=phi, delta=None, mline=self.main_line,
                                side=True, right=True)
-        self.left_line.update(phi=phi, delta=None,
-                              mline=self.main_line, side=True)
+        self.left_line.update(phi=phi, delta=None, mline=self.main_line,
+                              side=True, left=True)
         # Post the new corresponding data
         self._post_data(nbins=self.nbins)
+        self.draw()
 
     def draw(self):
         """
@@ -276,7 +293,10 @@ class SectorInteractor(BaseInteractor, SlicerModel):
 
 class SideInteractor(BaseInteractor):
     """
-    Draw an oblique line
+    Draws a line though 0,0 on a data2D plot with reference to a center line.
+    This is used to define both a left and right line which are always updated
+    together as they must remain symmetric at some phi value around the main
+    line (at -phi and +phi).
 
     :param phi: the phase between the middle line and one side line
     :param theta2: the angle between the middle line and x- axis
@@ -394,7 +414,7 @@ class SideInteractor(BaseInteractor):
         self.has_move = False
         self.base.moveend(ev)
 
-    def restore(self):
+    def restore(self, ev):
         """
         Restore the roughness for this layer.
         """
@@ -408,44 +428,45 @@ class SideInteractor(BaseInteractor):
         self.has_move = True
         if not self.left_moving:
             if  self.theta2 - self.theta <= 0 and self.theta2 > 0:
-                self.restore()
+                self.restore(ev)
                 return
             elif self.theta2 < 0 and self.theta < 0 and \
                 self.theta - self.theta2 >= 0:
-                self.restore()
+                self.restore(ev)
                 return
             elif  self.theta2 < 0 and self.theta > 0 and \
                 (self.theta2 + 2 * numpy.pi - self.theta) >= numpy.pi / 2:
-                self.restore()
+                self.restore(ev)
                 return
             elif  self.theta2 < 0 and self.theta < 0 and \
                 (self.theta2 - self.theta) >= numpy.pi / 2:
-                self.restore()
+                self.restore(ev)
                 return
             elif self.theta2 > 0 and (self.theta2 - self.theta >= numpy.pi / 2 or \
                 (self.theta2 - self.theta >= numpy.pi / 2)):
-                self.restore()
+                self.restore(ev)
                 return
         else:
             if  self.theta < 0 and (self.theta + numpy.pi * 2 - self.theta2) <= 0:
-                self.restore()
+                self.restore(ev)
                 return
             elif self.theta2 < 0 and (self.theta - self.theta2) <= 0:
-                self.restore()
+                self.restore(ev)
                 return
             elif  self.theta > 0 and self.theta - self.theta2 <= 0:
-                self.restore()
+                self.restore(ev)
                 return
             elif self.theta - self.theta2 >= numpy.pi / 2 or  \
                 ((self.theta + numpy.pi * 2 - self.theta2) >= numpy.pi / 2 and \
                  self.theta < 0 and self.theta2 > 0):
-                self.restore()
+                self.restore(ev)
                 return
 
         self.phi = numpy.fabs(self.theta2 - self.theta)
         if self.phi > numpy.pi:
             self.phi = 2 * numpy.pi - numpy.fabs(self.theta2 - self.theta)
-        self.base.base.update()
+        self.base.update()
+        self.base.draw()
 
     def set_cursor(self, x, y):
         self.move(x, y, None)
@@ -464,10 +485,16 @@ class SideInteractor(BaseInteractor):
 
 class LineInteractor(BaseInteractor):
     """
-    Select an annulus through a 2D plot
+    Draws a line though 0,0 on a data2D plot. This is used to define the
+    centerline around with other lines can be drawn to define a region of
+    interest (such as a sector).
+
+    :param theta: the angle between the middle line and x- axis
+    :param half_length: Defaults to False. If True, the line is drawn from the
+                        origin rather than across the whole graph.
     """
     def __init__(self, base, axes, color='black',
-                 zorder=5, r=1.0, theta=numpy.pi / 4):
+                 zorder=5, r=1.0, theta=numpy.pi / 4, half_length=False):
         BaseInteractor.__init__(self, base, axes, color=color)
 
         self.markers = []
@@ -477,11 +504,16 @@ class LineInteractor(BaseInteractor):
         self.theta = theta
         self.radius = r
         self.scale = 10.0
+        self.half_length = half_length
         # Inner circle
         x1 = self.radius * numpy.cos(self.theta)
         y1 = self.radius * numpy.sin(self.theta)
-        x2 = -1 * self.radius * numpy.cos(self.theta)
-        y2 = -1 * self.radius * numpy.sin(self.theta)
+        if not half_length:
+            x2 = -1 * self.radius * numpy.cos(self.theta)
+            y2 = -1 * self.radius * numpy.sin(self.theta)
+        else:
+            x2 = 0
+            y2 = 0
         # Inner circle marker
         self.inner_marker = self.axes.plot([x1 / 2.5], [y1 / 2.5], linestyle='',
                                            marker='s', markersize=10,
@@ -492,7 +524,6 @@ class LineInteractor(BaseInteractor):
         self.line = self.axes.plot([x1, x2], [y1, y2],
                                    linestyle='-', marker='',
                                    color=self.color, visible=True)[0]
-        self.npts = 20
         self.has_move = False
         self.connect_markers([self.inner_marker, self.line])
         self.update()
@@ -520,8 +551,12 @@ class LineInteractor(BaseInteractor):
             self.theta = theta
         x1 = self.radius * numpy.cos(self.theta)
         y1 = self.radius * numpy.sin(self.theta)
-        x2 = -1 * self.radius * numpy.cos(self.theta)
-        y2 = -1 * self.radius * numpy.sin(self.theta)
+        if not self.half_length:
+            x2 = -1 * self.radius * numpy.cos(self.theta)
+            y2 = -1 * self.radius * numpy.sin(self.theta)
+        else:
+            x2 = 0
+            y2 = 0
 
         self.inner_marker.set(xdata=[x1 / 2.5], ydata=[y1 / 2.5])
         self.line.set(xdata=[x1, x2], ydata=[y1, y2])
@@ -537,7 +572,7 @@ class LineInteractor(BaseInteractor):
         self.has_move = False
         self.base.moveend(ev)
 
-    def restore(self):
+    def restore(self, ev):
         """
         Restore the roughness for this layer.
         """
@@ -549,7 +584,8 @@ class LineInteractor(BaseInteractor):
         """
         self.theta = numpy.arctan2(y, x)
         self.has_move = True
-        self.base.base.update()
+        self.base.update()
+        self.base.draw()
 
     def set_cursor(self, x, y):
         self.move(x, y, None)
