@@ -1,26 +1,17 @@
 import sys
-import unittest
 from collections import OrderedDict
 
-from UnitTesting.TestUtils import WarningTestNotImplemented
+from sas.qtgui.UnitTesting.TestUtils import WarningTestNotImplemented
 
 # Tested module
 import sas.qtgui.Plotting.PlotUtilities as PlotUtilities
 
-class PlotUtilitiesTest(unittest.TestCase):
-    '''Test the Plot Utilities functions'''
-    def setUp(self):
-        '''Empty'''
-        pass
-
-    def tearDown(self):
-        '''Empty'''
-        pass
+class PlotUtilitiesTest:
 
     def testDefaults(self):
         """ default method variables values """
-        self.assertIsInstance(PlotUtilities.SHAPES, OrderedDict)
-        self.assertIsInstance(PlotUtilities.COLORS, OrderedDict)
+        assert isinstance(PlotUtilities.SHAPES, OrderedDict)
+        assert isinstance(PlotUtilities.COLORS, OrderedDict)
 
     def testBuildMatrix(self):
         """ build matrix for 2d plot from a vector """
@@ -41,6 +32,3 @@ class PlotUtilitiesTest(unittest.TestCase):
     def testGgetValidColor(self):
         """ test that the method returns a color understood by MPL """
         WarningTestNotImplemented()
-
-if __name__ == "__main__":
-    unittest.main()
