@@ -2,7 +2,7 @@
 Allows users to change the title of the current graph
 from "Graph_n" to any ASCII text.
 """
-from PyQt5 import QtWidgets, QtCore
+from PySide6 import QtWidgets, QtCore
 
 from sas.qtgui.Plotting.UI.WindowTitleUI import Ui_WindowTitle
 
@@ -11,8 +11,6 @@ class WindowTitle(QtWidgets.QDialog, Ui_WindowTitle):
     def __init__(self, parent=None, new_title=""):
         super(WindowTitle, self).__init__(parent)
         self.setupUi(self)
-        # disable the context help icon
-        self.setWindowFlags(self.windowFlags() & ~QtCore.Qt.WindowContextHelpButtonHint)
 
         self.txtTitle.setText(new_title)
 
