@@ -1,29 +1,24 @@
 import sys
-import unittest
 
-from PyQt5.QtGui import *
-from PyQt5.QtWidgets import *
-from PyQt5.QtTest import QTest
-from PyQt5.QtCore import *
-from unittest.mock import MagicMock
+from PySide6.QtGui import *
+from PySide6.QtWidgets import *
+from PySide6.QtTest import QTest
+from PySide6.QtCore import *
 
 # Local
 from sas.qtgui.Utilities.GuiUtils import Communicate
 from sas.qtgui.UnitTesting.TestUtils import *
 
-if not QApplication.instance():
-    app = QApplication(sys.argv)
-
-class TestUtilsTest(unittest.TestCase):
+class TestUtilsTest:
     '''Test TestUtils'''
 
-    def testQtSignalSpy(self):
+    def testQtSignalSpy(self, qapp):
         '''Create the Spy the correct way'''
         test_string = 'my precious'
 
         def signalReceived(signal):
             # Test the signal callback
-            self.assertEqual(signal, test_string)
+            assert signal == test_string
 
         communicator = Communicate()
         communicator.statusBarUpdateSignal.connect(signalReceived)
@@ -36,7 +31,4 @@ class TestUtilsTest(unittest.TestCase):
         communicator.statusBarUpdateSignal.emit(test_string)
 
         # Was the signal caught by the signal spy?
-        self.assertEqual(spy.count(), 1)
-
-if __name__ == "__main__":
-    unittest.main()
+        assert spy.count() == 1
