@@ -7,23 +7,25 @@ import logging
 
 import numpy as np
 
-from PyQt5 import QtWidgets, QtCore, QtGui
+from PySide6 import QtWidgets, QtCore, QtGui
+from PySide6.QtCore import QSize
+from PySide6.QtGui import QIcon
 
-from sas.sascalc.file_converter.ascii2d_loader import ASCII2DLoader
-from sas.sascalc.file_converter.nxcansas_writer import NXcanSASWriter
-from sas.sascalc.dataloader.data_info import Data1D
+from sasdata.file_converter.ascii2d_loader import ASCII2DLoader
+from sasdata.file_converter.nxcansas_writer import NXcanSASWriter
+from sasdata.dataloader.data_info import Data1D
 
-from sas.sascalc.dataloader.data_info import Detector
-from sas.sascalc.dataloader.data_info import Sample
-from sas.sascalc.dataloader.data_info import Source
-from sas.sascalc.dataloader.data_info import Vector
+from sasdata.dataloader.data_info import Detector
+from sasdata.dataloader.data_info import Sample
+from sasdata.dataloader.data_info import Source
+from sasdata.dataloader.data_info import Vector
 
-import sas.sascalc.file_converter.FileConverterUtilities as Utilities
+import sasdata.file_converter.FileConverterUtilities as Utilities
 
 import sas.qtgui.Utilities.GuiUtils as GuiUtils
 from sas.qtgui.Utilities.FrameSelect import FrameSelect
 
-from sas.sasview import __version__ as SASVIEW_VERSION
+from sas.system import version
 
 from .UI.FileConverterUI import Ui_FileConverterUI
 
@@ -42,12 +44,13 @@ class FileConverterWidget(QtWidgets.QDialog, Ui_FileConverterUI):
         self.parent = parent
         self.setupUi(self)
 
-        # disable the context help icon
-        self.setWindowFlags(self.windowFlags() & ~QtCore.Qt.WindowContextHelpButtonHint)
-
-
         self.setWindowTitle("File Converter")
 
+        icon = QIcon()
+        icon.addFile(u":/res/ball.ico", QSize(), QIcon.Normal, QIcon.Off)
+        self.setWindowIcon(icon)
+
+
         # i,q file fields are not editable
         self.txtIFile.setEnabled(False)
         self.txtQFile.setEnabled(False)
@@ -284,7 +287,7 @@ class FileConverterWidget(QtWidgets.QDialog, Ui_FileConverterUI):
             'detector': [self.getDetectorMetadata()],
             'sample': self.getSampleMetadata(),
             'source': self.getSourceMetadata(),
-            'notes': [f'Data file generated by SasView v{SASVIEW_VERSION}'],
+            'notes': [f'Data file generated by SasView v{version.__version__}'],
         }
         self.metadata = metadata
 
@@ -294,14 +297,11 @@ class FileConverterWidget(QtWidgets.QDialog, Ui_FileConverterUI):
         """
         wildcard1d = "CanSAS 1D files(*.xml);;" if self.is1D else ""
         wildcard = wildcard1d + "NXcanSAS files (*.h5)"
-        kwargs = {
-            'caption'   : 'Save As',
-            'filter'    : wildcard,
-            'parent'    : None,
-            'options'   : QtWidgets.QFileDialog.DontUseNativeDialog
-        }
+        caption = 'Save As'
+        filter = wildcard
+        parent = None
         # Query user for filename.
-        filename_tuple = QtWidgets.QFileDialog.getSaveFileName(**kwargs)
+        filename_tuple = QtWidgets.QFileDialog.getSaveFileName(parent, caption, "", filter, "")
         filename = filename_tuple[0]
 
         # User cancelled.
