@@ -1,8 +1,8 @@
-from PyQt5 import QtCore
-from PyQt5 import QtGui
-from PyQt5 import QtWidgets
+from PySide6 import QtCore
+from PySide6 import QtGui
+from PySide6 import QtWidgets
 
-from PyQt5 import QtSvg
+from PySide6 import QtSvg
 
 from sas.qtgui.Utilities import GuiUtils
 
