@@ -5,9 +5,10 @@ FitPanel class contains fields allowing to fit  models and  data
 import sys
 import datetime
 
-from PyQt5 import QtCore
-from PyQt5 import QtGui
-from PyQt5 import QtWidgets
+from PySide6 import QtCore
+from PySide6 import QtGui
+from PySide6 import QtWidgets
+
 
 class ResultPanel(QtWidgets.QTabWidget):
     """
@@ -19,7 +20,7 @@ class ResultPanel(QtWidgets.QTabWidget):
     """
     ## Internal name for the AUI manager
     window_name = "Result panel"
-    windowClosedSignal = QtCore.pyqtSignal()
+    windowClosedSignal = QtCore.Signal()
 
     def __init__(self, parent, manager=None, *args, **kwargs):
         """
