@@ -1062,66 +1062,67 @@ class OMFReader(object):
                 # Reading Header; Segment count ignored
                     s_line = line.split(":", 1)
                     if s_line[0].lower().count("oommf") > 0:
-                        oommf = s_line[1].lstrip()
+                        if len(s_line) < 2: s_line = line.split(" ",1)
+                        oommf = s_line[1].strip()                               
+
                     if s_line[0].lower().count("title") > 0:
-                        title = s_line[1].lstrip()
+                        title = s_line[1].strip()
                     if s_line[0].lower().count("desc") > 0:
-                        desc += s_line[1].lstrip()
+                        desc += s_line[1].strip()
                         desc += '\n'
                     if s_line[0].lower().count("meshtype") > 0:
-                        meshtype = s_line[1].lstrip()
+                        meshtype = s_line[1].strip()
                     if s_line[0].lower().count("meshunit") > 0:
-                        meshunit = s_line[1].lstrip()
+                        meshunit = s_line[1].strip()
                         if meshunit.count("m") < 1:
                             msg = "Error: \n"
                             msg += "We accept only m as meshunit"
                             logging.error(msg)
                             return None
                     if s_line[0].lower().count("xbase") > 0:
-                        xbase = s_line[1].lstrip()
+                        xbase = s_line[1].strip()
                     if s_line[0].lower().count("ybase") > 0:
-                        ybase = s_line[1].lstrip()
+                        ybase = s_line[1].strip()
                     if s_line[0].lower().count("zbase") > 0:
-                        zbase = s_line[1].lstrip()
+                        zbase = s_line[1].strip()
                     if s_line[0].lower().count("xstepsize") > 0:
-                        xstepsize = s_line[1].lstrip() 
+                        xstepsize = s_line[1].strip() 
                     if s_line[0].lower().count("ystepsize") > 0:
-                        ystepsize = s_line[1].lstrip()   
+                        ystepsize = s_line[1].strip()   
                     if s_line[0].lower().count("zstepsize") > 0:
-                        zstepsize = s_line[1].lstrip()
+                        zstepsize = s_line[1].strip()
                     if s_line[0].lower().count("xnodes") > 0:
-                        xnodes = s_line[1].lstrip()   
-                    #print(s_line[0].lower().count("ynodes"))
+                        xnodes = s_line[1].strip()   
                     if s_line[0].lower().count("ynodes") > 0:
-                        ynodes = s_line[1].lstrip()
-                        #print(ynodes)
+                        ynodes = s_line[1].strip()
                     if s_line[0].lower().count("znodes") > 0:
-                        znodes = s_line[1].lstrip()  
+                        znodes = s_line[1].strip()  
                     if s_line[0].lower().count("xmin") > 0:
-                        xmin = s_line[1].lstrip()
+                        xmin = s_line[1].strip()
                     if s_line[0].lower().count("ymin") > 0:
-                        ymin = s_line[1].lstrip()
+                        ymin = s_line[1].strip()
                     if s_line[0].lower().count("zmin") > 0:
-                        zmin = s_line[1].lstrip()
+                        zmin = s_line[1].strip()
                     if s_line[0].lower().count("xmax") > 0:
-                        xmax = s_line[1].lstrip()
+                        xmax = s_line[1].strip()
                     if s_line[0].lower().count("ymax") > 0:
-                        ymax = s_line[1].lstrip()
+                        ymax = s_line[1].strip()
                     if s_line[0].lower().count("zmax") > 0:
-                        zmax = s_line[1].lstrip()
+                        zmax = s_line[1].strip()
                     if s_line[0].lower().count("valueunit") > 0:
-                        valueunit = s_line[1].lstrip()
+                        valueunit = s_line[1].strip()
                         if valueunit.count("mT") < 1 and valueunit.count("A/m") < 1: 
                             msg = "Error: \n"
                             msg += "We accept only mT or A/m as valueunit"
                             logging.error(msg)    
                             return None
+                        elif "mT" in valueunit or "A/m" in valueunit:    
+                            valueunit = valueunit.split(" ", 1)
+                            valueunit = valueunit[0].strip()
                     if s_line[0].lower().count("valuemultiplier") > 0:
-                        valuemultiplier = s_line[1].lstrip()
-                    if s_line[0].lower().count("valuerangeminmag") > 0:
-                        valuerangeminmag = s_line[1].lstrip()
-                    if s_line[0].lower().count("valuerangemaxmag") > 0:
-                        valuerangemaxmag = s_line[1].lstrip()
+                        valuemultiplier = s_line[1].strip()
+                    else: 
+                        valuemultiplier = 1
                     if s_line[0].lower().count("end") > 0:
                         output.filename = os.path.basename(path)
                         output.oommf = oommf
@@ -1144,10 +1145,6 @@ class OMFReader(object):
                         output.ymax = float(ymax) * METER2ANG
                         output.zmax = float(zmax) * METER2ANG
                         output.valuemultiplier = valuemultiplier
-                        output.valuerangeminmag \
-                            = mag2sld(float(valuerangeminmag), valueunit)
-                        output.valuerangemaxmag \
-                            = mag2sld(float(valuerangemaxmag), valueunit)
             mx = np.reshape(mx, (len(mx),))
             my = np.reshape(my, (len(my),))
             mz = np.reshape(mz, (len(mz),))
@@ -1166,6 +1163,9 @@ class PDBReader(object):
     """
     PDB reader class: limited for reading the lines starting with 'ATOM'
     """
+
+    logger = logging.getLogger("sas_gen.PDBReader")
+
     type_name = "PDB"
     ## Wildcards
     type = ["pdb files (*.PDB, *.pdb)|*.pdb"]
@@ -1189,12 +1189,10 @@ class PDBReader(object):
         sld_mz = []
         vol_pix = []
         pix_symbol = []
-        x_line = []
-        y_line = []
-        z_line = []
-        x_lines = []
-        y_lines = []
-        z_lines = []
+        connected_pairs = set()
+
+        atom_value_dict = {}
+
         try:
             input_f = open(path, 'rb')
             buff = decode(input_f.read())
@@ -1225,61 +1223,83 @@ class PDBReader(object):
                         pos_y.append(_pos_y)
                         pos_z.append(_pos_z)
                         try:
-                            val = nsf.neutron_sld(atom_name)[0]
-                            # sld in Ang^-2 unit
-                            val *= 1.0e-6
-                            sld_n.append(val)
-                            atom = formula(atom_name)
-                            # cm to A units
-                            vol = 1.0e+24 * atom.mass / atom.density / NA
-                            vol_pix.append(vol)
+                            if atom_name in atom_value_dict:
+                                sld_n.append(atom_value_dict[atom_name][0])
+                                vol_pix.append(atom_value_dict[atom_name][1])
+                            else:
+                                val = nsf.neutron_sld(atom_name)[0]
+                                # sld in Ang^-2 unit
+                                val *= 1.0e-6
+                                sld_n.append(val)
+                                atom = formula(atom_name)
+                                # # cm to A units
+                                vol = 1.0e+24 * atom.mass / atom.density / NA
+                                vol_pix.append(vol)
+                                atom_value_dict[atom_name] = [val, vol]
+
                         except Exception:
-                            logging.warning("Warning: set the sld of %s to zero"% atom_name)
+                            self.logger.warning("Warning: set the sld of %s to zero"% atom_name)
                             sld_n.append(0.0)
+
                         sld_mx.append(0)
                         sld_my.append(0)
                         sld_mz.append(0)
                         pix_symbol.append(atom_name)
 
                     elif line[0:6] == 'CONECT':
-                        toks = line.split()
-                        num = int(toks[1]) - 1
-                        val_list = []
-                        for val in toks[2:]:
+                        # Interpret the bonding section of the PDB
+
+                        # split remainder of line into 5 character sections
+                        rest = line[6:]
+                        parts = [rest[i:i+5] for i in range(0, len(rest), 5)]
+
+                        # Convert to indices
+                        bonded_indices = []
+                        for part in parts:
+
                             try:
-                                int_val = int(val)
-                            except Exception:
-                                break
-                            if int_val == 0:
-                                break
-                            val_list.append(int_val)
-                        # need val_list ordered
-                        for val in val_list:
-                            index = val - 1
-                            if (pos_x[index], pos_x[num]) in x_line and \
-                               (pos_y[index], pos_y[num]) in y_line and \
-                               (pos_z[index], pos_z[num]) in z_line:
-                                continue
-                            x_line.append((pos_x[num], pos_x[index]))
-                            y_line.append((pos_y[num], pos_y[index]))
-                            z_line.append((pos_z[num], pos_z[index]))
-                    if len(x_line) > 0:
-                        x_lines.append(x_line)
-                        y_lines.append(y_line)
-                        z_lines.append(z_line)
+                                index = int(part) - 1
+                                bonded_indices.append(index)
+
+                            except ValueError as ve:
+                                pass
+
+                        # Store pairs in canonical order
+                        a = bonded_indices[0]
+                        for b in bonded_indices[1:]:
+                            if a > b:
+                                a, b = b, a
+                            connected_pairs.add((a, b))
+
                 except Exception as exc:
-                    logging.error(exc)
-            pos_x = np.reshape(pos_x, (len(pos_x),))
-            pos_y = np.reshape(pos_y, (len(pos_y),))
-            pos_z = np.reshape(pos_z, (len(pos_z),))    
-            sld_n = np.reshape(sld_n, (len(sld_n),)) 
-            sld_mx = np.reshape(sld_mx, (len(sld_mx),))    
-            sld_my = np.reshape(sld_my, (len(sld_my),)) 
-            sld_mz = np.reshape(sld_mz, (len(sld_mz),))  
-            vol_pix = np.reshape(vol_pix, (len(vol_pix),))   
-            pix_symbol = np.reshape(pix_symbol, (len(pix_symbol),))                                                             
+                    self.logger.error(f"Failed to read line: {line}")
+                    self.logger.exception(exc)
+                    self.logger.error(f"Aborting reading of file {path}.")
+                    return None
+
+            # Reshape stuff for file
+
+            pos_x = np.reshape(pos_x, (-1, ))
+            pos_y = np.reshape(pos_y, (-1, ))
+            pos_z = np.reshape(pos_z, (-1, ))
+
+            n_atoms = len(pos_x)
+            ordered_pairs = sorted([(a, b) for a, b in connected_pairs if a < n_atoms and b < n_atoms])  # Why *not* sort
+            x_lines = [(pos_x[a], pos_x[b]) for a, b in ordered_pairs]
+            y_lines = [(pos_y[a], pos_y[b]) for a, b in ordered_pairs]
+            z_lines = [(pos_z[a], pos_z[b]) for a, b in ordered_pairs]
+
+            sld_n = np.reshape(sld_n, (-1, ))
+
+            sld_mx = np.reshape(sld_mx, (-1, ))
+            sld_my = np.reshape(sld_my, (-1, ))
+            sld_mz = np.reshape(sld_mz, (-1, ))
+
+            vol_pix = np.reshape(vol_pix, (-1, ))
+            pix_symbol = np.reshape(pix_symbol, (-1, ))
+
             output = MagSLD(pos_x, pos_y, pos_z, sld_n, sld_mx, sld_my, sld_mz)
-            output.set_conect_lines(x_line, y_line, z_line)
+            output.set_conect_lines(x_lines, y_lines, z_lines)
             output.filename = os.path.basename(path)
             output.set_pix_type('atom')
             output.set_pixel_symbols(pix_symbol)
@@ -1287,8 +1307,9 @@ class PDBReader(object):
             output.set_pixel_volumes(vol_pix)
             output.sld_unit = '1/A^(2)'
             return output
-        except Exception:
-            logging.error("%s is not a pdb file" % path)
+
+        except Exception as e:
+            self.logger.exception(e)
             return None
 
     def write(self, path, data):
@@ -1379,7 +1400,7 @@ class SLDReader(object):
             np.savetxt(out, columns)
 
 
-class OMFData(object):
+class OMFData:
     """
     OMF Data.
     """
@@ -1415,8 +1436,7 @@ class OMFData(object):
         self.my = None
         self.mz = None
         self.valuemultiplier = 1.
-        self.valuerangeminmag = 0
-        self.valuerangemaxmag = 0
+
 
     def __str__(self):
         """
@@ -1449,10 +1469,7 @@ class OMFData(object):
         _str += "zmax:            %s [%s]\n" % (str(self.zmax), self.meshunit)
         _str += "valueunit:       %s\n" % self.valueunit
         _str += "valuemultiplier: %s\n" % str(self.valuemultiplier)
-        _str += "ValueRangeMinMag:%s [%s]\n" % (str(self.valuerangeminmag),
-                                                self.valueunit)
-        _str += "ValueRangeMaxMag:%s [%s]\n" % (str(self.valuerangemaxmag),
-                                                self.valueunit)
+
         return _str
 
     def set_m(self, mx, my, mz):
@@ -1488,36 +1505,42 @@ class MagSLD(object):
         self.is_data = True
         self.is_elements = False # is this a finite-element based mesh
         self.are_elements_array = False # are all elements of the same type
+
         self.elements = []
         self.filename = ''
+
         self.xstepsize = 6.0
         self.ystepsize = 6.0
         self.zstepsize = 6.0
+
         self.xnodes = 10.0
         self.ynodes = 10.0
         self.znodes = 10.0
+
         self.has_stepsize = False
         self.has_conect = False
         self.pos_unit = self._pos_unit
         self.sld_unit = self._sld_unit
         self.pix_type = 'pixel' if vol_pix is None else 'atom'
+
         self.pos_x = np.asarray(pos_x, 'd')
         self.pos_y = np.asarray(pos_y, 'd')
         self.pos_z = np.asarray(pos_z, 'd')
+
         self.sld_n = np.asarray(sld_n, 'd')
-        self.line_x = None
-        self.line_y = None
-        self.line_z = None
+
+        self.line_x: list[tuple[float, float]] | None = None
+        self.line_y: list[tuple[float, float]] | None = None
+        self.line_z: list[tuple[float, float]] | None = None
+
         self.sld_mx = sld_mx
         self.sld_my = sld_my
         self.sld_mz = sld_mz
+
         self.vol_pix = vol_pix
         self.data_length = len(pos_x)
-        #self.sld_m = None
-        #self.sld_phi = None
-        #self.sld_theta = None
-        #self.sld_phi = None
         self.pix_symbol = None
+
         if sld_mx is not None and sld_my is not None and sld_mz is not None:
             self.set_sldms(sld_mx, sld_my, sld_mz)
         if vol_pix is None:
@@ -1584,11 +1607,6 @@ class MagSLD(object):
         else:
             self.sld_mz = sld_mz
 
-        #sld_m = np.sqrt(sld_mx**2 + sld_my**2 + sld_mz**2)
-        #if isinstance(sld_m, float):
-        #    self.sld_m = np.full_like(self.pos_x, sld_m)
-        #else:
-        #    self.sld_m = sld_m
 
     def set_pixel_symbols(self, symbol='pixel'):
         """
@@ -1708,16 +1726,13 @@ class MagSLD(object):
             self.has_stepsize = True
         return self.xstepsize, self.ystepsize, self.zstepsize
 
-    def set_conect_lines(self, line_x, line_y, line_z):
+    def set_conect_lines(self,
+                         line_x: list[tuple[float, float]],
+                         line_y: list[tuple[float, float]],
+                         line_z: list[tuple[float, float]]):
         """
         Set bonding line data if taken from pdb
         """
-        if line_x.__class__.__name__ != 'list' or len(line_x) < 1:
-            return
-        if line_y.__class__.__name__ != 'list' or len(line_y) < 1:
-            return
-        if line_z.__class__.__name__ != 'list' or len(line_z) < 1:
-            return
         self.has_conect = True
         self.line_x = line_x
         self.line_y = line_y
@@ -1889,7 +1904,7 @@ def realspace_Iq(self, qx, qy):
         if is_magnetic:
             I_out = calc_Iq_magnetic(
                 qx, qy, rho, rho_m, points, volume,
-                up_frac_i=in_spin, up_frac_f=out_spin, up_angle=s_theta, up_phi=s_phi,
+                up_frac_i=in_spin, up_frac_f=out_spin, up_theta=s_theta, up_phi=s_phi,
                 )
         else:
             I_out = calc_Iqxy(qx, qy, rho, points, volume=volume, dtype='d')
@@ -2106,12 +2121,12 @@ def demo_shape(shape='ellip', samples=2000, nq=100, view=(60, 30, 0),
         rho, rho_m, points = shape.sample_magnetic(sampling_density)
         rho, rho_m = rho*1e-6, rho_m*1e-6
         mx, my, mz = rho_m
-        up_i, up_f, up_angle, up_phi = shape.spin
+        up_i, up_f, up_theta, up_phi = shape.spin
     else:
         rho, points = shape.sample(sampling_density)
         rho = rho*1e-6
         mx = my = mz = None
-        up_i, up_f, up_angle, up_phi = 0.5, 0.5, 90.0, 0.0
+        up_i, up_f, up_theta, up_phi = 0.5, 0.5, 90.0, 0.0
     points = realspace.apply_view(points, view)
     volume = shape.volume / len(points)
     #print("shape, pixel volume", shape.volume, shape.volume/len(points))
@@ -2126,7 +2141,7 @@ def demo_shape(shape='ellip', samples=2000, nq=100, view=(60, 30, 0),
     model.params['background'] = 1e-2
     model.params['Up_frac_in'] = up_i
     model.params['Up_frac_out'] = up_f
-    model.params['Up_theta'] = up_angle
+    model.params['Up_theta'] = up_theta
     model.params['Up_phi'] = up_phi
     if use_2d or shape.is_magnetic:
         q = np.linspace(-qmax, qmax, nq)
@@ -2162,7 +2177,7 @@ def demo():
         # Shape + qrange + magnetism (only for ellip).
         #shape='ellip', rab=125, rc=50, qmax=0.1,
         #shape='ellip', rab=25, rc=50, qmax=0.1,
-        shape='ellip', rab=125, rc=50, qmax=0.05, rho_m=5, theta_m=20, phi_m=30, up_i=1, up_f=0, up_angle=35, up_phi=35,
+        shape='ellip', rab=125, rc=50, qmax=0.05, rho_m=5, theta_m=20, phi_m=30, up_i=1, up_f=0, up_theta=35, up_phi=35,
 
         # 1D or 2D curve (ignored for magnetism).
         #use_2d=False,
