@@ -1,13 +1,12 @@
 from sas.sascalc.data_util.calcthread import CalcThread
-from sas.sascalc.dataloader.data_info import Data1D
+from sasdata.dataloader.data_info import Data1D
 from scipy.fftpack import dct
-from scipy.integrate import trapz, cumtrapz
+from scipy.integrate import trapezoid, cumulative_trapezoid
 import numpy as np
-from time import sleep
 
 class FourierThread(CalcThread):
     def __init__(self, raw_data, extrapolated_data, bg, updatefn=None,
-        completefn=None):
+                 completefn=None):
         CalcThread.__init__(self, updatefn=updatefn, completefn=completefn)
         self.data = raw_data
         self.background = bg
@@ -15,7 +14,7 @@ class FourierThread(CalcThread):
 
     def check_if_cancelled(self):
         if self.isquit():
-            self.update("Fourier transform cancelled.")
+            self.update("Fourier transform cancelled.") # TODO: This doesn't fit the signature of the function being called
             self.complete(transforms=None)
             return True
         return False
@@ -35,7 +34,7 @@ class FourierThread(CalcThread):
         if self.check_if_cancelled(): return
         try:
             # ----- 1D Correlation Function -----
-            gamma1 = dct((iqs-background)*qs**2)
+            gamma1 = dct((iqs-background)*(qs**2))
             Q = gamma1.max()
             gamma1 /= Q
 
@@ -45,7 +44,7 @@ class FourierThread(CalcThread):
             # gamma3(R) = 1/R int_{0}^{R} gamma1(x) dx
             # numerical approximation for increasing R using the trapezium rule
             # Note: SasView 4.x series limited the range to xs <= 1000.0
-            gamma3 = cumtrapz(gamma1, xs)/xs[1:]
+            gamma3 = cumulative_trapezoid(gamma1, xs)/xs[1:]
             gamma3 = np.hstack((1.0, gamma3)) # gamma3(0) is defined as 1
 
             if self.check_if_cancelled(): return
@@ -59,7 +58,7 @@ class FourierThread(CalcThread):
             # very large negative value.
             # IDF(x) = int_0^inf q^4 * I(q) * cos(q*x) * dq
             # => IDF(0) = int_0^inf q^4 * I(q) * dq
-            idf[0] = trapz(-qs**4 * (iqs-background), qs)
+            idf[0] = trapezoid(-qs**4 * (iqs-background), qs)
             idf /= Q # Normalise using scattering invariant
 
         except Exception as e:
@@ -78,13 +77,13 @@ class FourierThread(CalcThread):
         transform3 = Data1D(xs, gamma3)
         idf = Data1D(xs, idf)
 
-        transforms = (transform1, transform3, idf)
+        transformed_data = (transform1, transform3, idf)
 
-        self.complete(transforms=transforms)
+        self.complete(transform_result=transformed_data)
 
 class HilbertThread(CalcThread):
     def __init__(self, raw_data, extrapolated_data, bg, updatefn=None,
-        completefn=None):
+                 completefn=None):
         CalcThread.__init__(self, updatefn=updatefn, completefn=completefn)
         self.data = raw_data
         self.background = bg
