@@ -6,8 +6,8 @@ import sys
 import math
 import numpy as np
 
-from sas.sascalc.dataloader.data_info import Data1D
-from sas.sascalc.dataloader.data_info import Data2D
+from sasdata.dataloader.data_info import Data1D
+from sasdata.dataloader.data_info import Data2D
 _SMALLVALUE = 1.0e-10
 
 class FitHandler(object):
@@ -161,7 +161,7 @@ class FitData1D(Data1D):
         # Check error bar; if no error bar found, set it constant(=1)
         # TODO: Should provide an option for users to set it like percent,
         # constant, or dy data
-        if dy is None or dy == [] or dy.all() == 0:
+        if dy is None or dy.size == 0 or np.all(dy == 0):
             self.dy = np.ones(len(y))
         else:
             self.dy = np.asarray(dy).copy()
@@ -299,7 +299,7 @@ class FitData2D(Data2D):
         if qmax is None:
             self.qmax = math.sqrt(x_max * x_max + y_max * y_max)
         ## new error image for fitting purpose
-        if self.err_data is None or self.err_data == []:
+        if self.err_data is None or self.err_data.size == 0:
             self.res_err_data = np.ones(len(self.data))
         else:
             self.res_err_data = copy.deepcopy(self.err_data)
@@ -394,8 +394,10 @@ class FitEngine:
         """
         #Dictionnary of fitArrange element (fit problems)
         self.fit_arrange_dict = {}
+        self.weight_increase = {}
         self.fitter_id = None
 
+
     def set_model(self, model, id, pars=[], constraints=[], data=None):
         """
         set a model on a given  in the fit engine.
@@ -503,6 +505,12 @@ class FitEngine:
         if id in self.fit_arrange_dict:
             self.fit_arrange_dict[id].get_to_fit()
 
+    def set_weight_increase(self, fit_id, weight_increase):
+        self.weight_increase[fit_id] = weight_increase
+
+    def get_weight_increase(self, fit_id):
+        return self.weight_increase[fit_id]
+
 
 class FitArrange:
     def __init__(self):
