@@ -437,9 +437,10 @@ class VolumeCanvas(BaseComponent):
 
     def getParamList(self, shapeid=None):
         """
-	       return a full list of all available parameters from
+....       return a full list of all available parameters from
            self.params.keys(). If a key in self.params is a instance
            of ShapeDescriptor, extend the return list to:
+           
            [param1,param2,shapeid.param1,shapeid.param2.......]
 
            If shapeid is provided, return the list of parameters that
