@@ -4,7 +4,7 @@
 
 import os.path
 import unittest
-from sas.sascalc.dataloader.readers.ascii_reader import Reader
+from sasdata.dataloader.readers.ascii_reader import Reader
 from sas.sascalc.calculator.slit_length_calculator import SlitlengthCalculator \
     as calculator
 
