@@ -12,8 +12,8 @@ import os.path
 import unittest
 import math
 import numpy as np
-from sas.sascalc.dataloader.loader import  Loader
-from sas.sascalc.dataloader.data_info import Data1D
+from sasdata.dataloader.loader import Loader
+from sasdata.dataloader.data_info import Data1D
 
 from sas.sascalc.invariant import invariant
 
